(function (root, factory) {
    if (typeof define === 'function' && define.amd) {
        // AMD. Register as an anonymous module.
        define(['exports', 'echarts'], factory);
    } else if (typeof exports === 'object' && typeof exports.nodeName !== 'string') {
        // CommonJS
        factory(exports, require('echarts'));
    } else {
        // Browser globals
        factory({}, root.echarts);
    }
}(this, function (exports, echarts) {
    var log = function (msg) {
        if (typeof console !== 'undefined') {
            console && console.error && console.error(msg);
        }
    }
    if (!echarts) {
        log('ECharts is not Loaded');
        return;
    }
    if (!echarts.registerMap) {
        log('ECharts Map is not loaded')
        return;
    }
    echarts.registerMap('新疆', {"type":"FeatureCollection","features":[{"id":"650100","type":"Feature","geometry":{"type":"Polygon","coordinates":["@@KmGqAMAKH@BKF@ALNA@EF@@AB@DPHBDLABEDABIBD\\DDBNHJVH@@DP@BDBABAD@@FB@L@DBFAJBBFHB@FA@@DD@EBFDLAAEDA@CFA@B@ZB@@BEBAJDBGFAAML@@@RFVBTFB@BCDG@@JHZHABBDJHN@DBFDD@FDDCJ@JAFDRAPDHTNDFBAHMDCEINAOACAACY@IRGBEDCJAdZBBhZKRPHCVldHĀ_VOFB}BCJELCNAPCHAH[FITUP_JQBEHCLJPFPObBHGNBVCD@DCH@HIHKRCF@BDBCLCD@FBBABDBADD@AHB@ABB@DHFDuÔǿ˪֘B_ƫүQyM_AlFÁě¨L@ABIFKFGHGF@ZAHEF@FMACBIAMDCBGDAAGDCBE`QDAFCNGRIdYPIJAHGHAPIDCLC@ADA`D`MBEHEDG@ECCCIBEAEDEBGHG@C@EFABINMHI@CLOAAEA@KDGDIAGDEFCBGAAKCII@CAIBGJI@EBCAA@EJCDEPEDEJEBAFCJCV@FAFABCFABCBBBC@SJICCDA@CDC@EDENCFKN@BFDDH@DB@DLDJEFBFAVEDUFOBEBA@KBA@CFC@ECEDICGCACUTFJBRCH@FB@DCJBFFD\\IXCDAJIDAFAFD@PBDL@LCP@HEDDFHRLJLLJCNEHEHGDADFDBFAFDHDBJ@B@HGH@RVFJHBJAFE^KFCDE@GGG@GBCHABA@MDELBXNNF\\G`BpAPCJGNAFBJJNJPJDFFDPELAL@RFNHJJDF@DDPLJBDDNDFTLH@LHHIAQFOFCTEDCBECI@GGGCEBEJMP@FFP@F@JGPAJDHFFCNAJ@VFAMBEBEJEJKJIFCAIBEPCNAXHJEJCDEDAF@NLF@DAJGHCH@HBHAHMJEJEXCHA@AEIBKKICCSCAADKAKDCV@NDD@JHVGP@NADABCD@TFH@HDPARNP@JH\\ERFH@FEBKH@PBDCHCBACINEBCBAPCBG\\WJALFF@FABCBICMDKHM@KDAFAHER@LC@MBAHACEBGEGDEHCBGFEBAVSFI@KGS@AFCDIDEVM@CFEBEBAGQCCCAAGEE@GCCEMECBGISKGGKIK@IBKAIBECOBIACICDKEM@EBIECACIEQAMAIEIAECUCMGIAEAKKGA@ECEOIEEECAC]FiDM@IBK@MD[@EAK@CBGBACEA@EGGEAIKC@ADCAK@CAI@EBY@EAAEIEIE[EEBOABGA@OEAAIAIGMCDIACMBS@EBG@EDCCG@GBADIA@FEBQCECCEICE@QH@ADEACE@ECM@EBCFE@AFA@KDEAIDKGCA@AFEAGECDC@KFEBGBAEEAEBMAAFECEBIEE@EBCAC@CHCDG@EAIOSUOGAKG_IGCGGECEYOOKMUEcQKAI@ODWJSDOF]RaTIBS@EIC@QDI@CACAAOACEAY@WJI@YF[BMF]x[hCL@PDPHNJHDXEF@BHBBBCDIDYAO@M@ONIEE@QDIBG@MCE@KCG@QJEBCKCAG@MBGAGCQAQ@OCSGC@CDKAICE@MDK@aEYIYOGCODONGHIBuI_CY@[IOCaCEBIAED]CI@QBCDMBQIIAQAoDaGYBMHWKW@KEQ@KCOAEFC@AI@AFA@EGGGCOACDa@MFQIEEWIaBKCoEQ@QAGD@HCBMAYAWHK@@CC@GBOA[FGE[@ABADEBCBI@UEMBKAGBYRK@[EKBCHGDE@IGGBCBMBM@G@EM@MLQBEDCDELQBIDOAEBA@EAADOAI@OJK@EHIBGEO@GOMFMAUDWCYDOBCLBN@HEFCFEJAVBNHJ@HCJ@HCRMJ@^HRAjUpcTCHOFCNANCZMRQJCRCZFJ@`IJEFMBK@IDMAKCMVGDARCNEhEHAVIUNEbIJEPMPWTKHEvKTObcj_JCHAPAvODA\\URITcLIBCCACCAAFUCGDGCIIC@QNMFQR[NKDEDMFCDAJGHC@S@EBMJQNADMHGJURSCGEIA_PSDEABEAEUAKBSHcFuBYCOECAkH_DWII@SHQBGHIBDF@DADEHAHSJEHsPYAaL_DUJQNI@YLWAcTOPkNMRGFUFmTcFYXQFEFYFgHGDmLQCOLF]FIDI@KBOHO@EA@aKCcQ[GGEEIIAO@GDIPIJEBSCCCCIkNSDGFELCDQCOGE@UH[@QFIBGHGJEJ@NADCBSEMPI@YNQDIAOGE@AFGFQBGDKHCFE@GBUJMBGNC@BDBFDFHFNDDFBFBLBFHD`FPJBDCRMDGFABIDEBSDBPVLFFJDFJ@DADDFPJJBHHDJDbJJHFNPDH@J@LFF^@FBBDBBB\\DTKRBD\\TXVCL@JDPDL`fAFA@CLMJUJCFE@EDGBCB@FGJBDADAHBHAD@BAD@DDH@BBDAFLFBFF@DDDFDD@BJDFDJJBHJDBBBHTDBBH@FHLA@DHDAFB@DBBAD@DAJFBDADBFAFFD@FDDFF@FDB@FDDBDJJ@HDFDXJJDBBFJF@BFB@BFBHHJBBDJBBDNF@BHBHHDFJHNHNBDDHBLJF@FFHDHBXNJLJHBDFJLJJNJJBDDHBBHH@DDFBHFBFF@DFHHHFB@DFDBFFD@FFFFBDDJDDFF@FFPFDBFDFDDRDDDDBDDDBDDFDRJNBJFDDHPPDBFJHH@DJHDD@DD@@BFB@FHDABD@DFLJBHBBDFBBF@FFABDDCBCCABBDF@FDADCDFF@FALBDADDLCFBD@JCHBDAJ@HAH@DDHEJALADAJED@HCDCPINBLAJ@HADFD@FFDDJFLFHLRJLJDBFHDJBDDHLFFBDFFBHDDTNFBFDFBLBBDE@HDBFB@BDHBLJCFFHHJNF@DDDLDPRFBLCBDFAD@BDFBHAH@BFHDDBF@CF@@VHLHNBJHFCH@BBD@JL@FDDCBBBdA@DLAhY"],"encodeOffsets":[[89605,45125]]},"properties":{"cp":[87.617733,43.792818],"name":"乌鲁木齐市","childNum":1}},{"id":"650200","type":"Feature","geometry":{"type":"MultiPolygon","coordinates":[["@@BU@CCEBE@KCOAAN@{KIEKIOGEAMAACBGACEEGMAQEMUOGAEE@ICEDGAOAE@CCEBOASCAEOS]EI[COIEAQAM@KASAIJMBKEIAEEAEGABCGCKBKFE@K@UCMGIGiYMG_OIEC@GDPdNLZ^TXFLJXHJFTPX@F@RNr@FENBNEZ@PCJMNABFTAJEHGb@XAL@`@^ǔMŜ"],["@@MGAE@AHCFEDADABEAAEAQDEFODCCM@CA@ADCAA[D@ADCJA@C@AE@IBACCACAI@BCEBE@CA@CG@@ABAAED@HEJBDA@AAEKBC@DGIAACI@BCE@BECAACOAMD@A@AC@CEEAKBA@BCEABEEE@CCAGAACI@BEG@DA@AGCE@BCEABCG@GC@CCAC@AABAC@EGC@CCEB@CBA@@GBCAEC@CE@BAEBCCDCEB@CCAG@@A@ACBCCBAC@@AACEAEB@ADAACE@@CA@BA@AGB@AC@@ACA@AC@BCIBBCCAGACBAABACABCC@@CEBBCI@DC@AGBAADCG@AAGABAE@EC@CCBCCBAG@BCIA@CG@@AA@BCEABAAACB@CE@@AE@@CEAAAIA@CM@@CEAAAC@CCC@cY@CBABCHC@ACCEAAABCCCIC]QIiIyi»AAHCBC@IDEICYWGKACGEGBACDCCCDGGAFC@CACSE@AEC@CK@CGC@E]MUCGiWQ]Ukwo}{YIeOyIC@OCOE_HKAAECAGKq_YiJKCCIQF]J_@QEaEUGMWcc_IQH]Bmvd_E]KUAGC[CyDC@IHGJCFEBODECI@CFEHMDMAEAEEE]QiJKFgDoM_©qUcW[eUuJuCSQWAWDUJQHIBEDCNEDEFADiSKwQOPOJEBGCOFGHUPINGREFUBKJiIeDpC@QEG@EEmQeGBI¼į£EE@GCCQE@IGG@CBIFEHA@ECEBADEA@HA@EHKD@H@BEDEBABAHCF@BEBAJCBAFOAKFGBCDCCI@EFAFBFHFCHGJE@@CC@KBCDMHSACBA@AB@DD@FF@@@DGDAJqTIRMJUL@NBBtAGÚ[BBTCxBV@^PAFvDJHEJGDDFFBfŲYTWTSNYtGHCHcZCJMLKGLFCDFABHFB@BD@DDDFRJh^@BNTFBCBFBDHDBBDBF@JCDLAADFBADB@@DCBBDADHFFBLCEFGLDABHDBB@BBD@BCHDAFDDH@CDBDEBHHD@CDR@EFD@DABDJDCBFJCND@BFH@DD@DFBBAL@@@ADBBADB@DCB@BDABBBDBDBDFCFBJHFBLB@FAFDEDGBLBD@AHF@DBCDDHADDB@NFBEFB@@BBBCDDBBBJ@CD@FF@CBD@ADBBADFBABBDCBGDBB@DFBED@DDBEHBHHDL@BDDB@DJFBDD@BBABDBIHD@BBABDBABB@AB@DD@DED@@BA@LJFJD@AD@BABFA@BCBADFD@BD@BBDDEFDA@DH@BBABBBFHH@DDD@BBJDJHBFFA@BADBBAF@DCFBBABUX[LK@BFCNBBLFLFDFADBDDBH@VKBGFCHALBJAPGCEAUNIHFDFNEJ@PD@FD@D@BBF@BBFABBJALBFD@BB@LFLDDALDB@D@DDCDF@FFBNFF@BDDAFFD@FFD@DBDNHDABDD@FHDJHFDHPJADB@DGBABDCHFBF@JED@BDF@EDBBJDLBHDF@HBDBRBBBFCAABCN@BFJB@DD@PEH@DAH@TC@CFBBA@BD@D@@AFBDA@DZJ@DH@VRDA@FDAF@DDLBBDFA@DF@DBHBBBD@ADF@@BC@HB@BH@BDCBF@@BFDDDD@BBCBDBHC@BABEBAD@@DAD@ADFCD@@B@DH@CDD@ABFB@BB@@DHBA@@BEBL@BDIFDBFFB@BDD@CD@BHBF@@BHBEDPCLD@BA@I@FBFDDFFB@BB@BBABD@FD@BC@DDBA@CJ@CDF@CDF@CDBBAB@BEDHAADD@BBD@@BDBFDBDABDFC@BB@BDBADBBFBBBDB@BEBH@ABC@BDC@F@BDIDHAJA@BABB@BBCB@BIBLA@BCBB@DABBHDSDFBHADDABG@BBC@HB@@CBFBDAADDA@DBBCBB@@DFFABHB@BM@DB@BDADBABA@DB@BC@DB@BDA@@AFADCB@DNC@BBAAD@FEBDDNBADD@@BGDKBPBABDA@BAB@FD@@BBDFBCDFC@FBAD@BDCBF@BBKJLEABD@@HEHGFEAABHDJCBDBCJF@DDBDADB@BABF@ADH@BBBBEBDFYDRD@BIDF@BDBEBAHDHAFFG@@DCBBB@BIECBAACBMA@BFBH@FBABGA@@HDGHDABBHEF@CFGFE@@HH@DKHCLDFFCDFADDADEDSDEA@A@AEDABDBABKBEACBD@ADHF@DFABDCBGAADDBD@BDFABDLAJ@BBFADD@BEBDBCDPEFB@HCABDG@BDADCDF@DBDH@BE@CA@F@@GGABA@OEJHD@FD@BKBH@FD@BE@@BDB@BI@BDFB@BOAHDEBDHCDK@@DAB@FAB@DABDBDFG@GFDB@DEDDBF@B@@BEDDB@FABD@BDABF@@HF@BBBBABBBADJ@GJJCCDDBAHDB@LHDTHXBPFFDLbLDNHpHNLPDFLTFB@DEHE@CHCF@NEDCDEN@HFHBHAFLDDCFAHJHFDL@DDFAzRD@BDC@BFPDFBJDHFF@FHNDTFJDFFNBPJVHZ@ZJBFP@FDJ@FAHDDDNDH@ZERBPDFCFKDCHA@CjQdDNARBà@^MPOFBJ@DDFADBVAB@DDZCPJbCfAPAò³JWBGJGDCACCABCNOHWRKBE@CeQeGqUA]QUAYFIWOMC@CDEDI"]],"encodeOffsets":[[[87157,45408]],[[88003,47086]]]},"properties":{"cp":[84.873946,45.595886],"name":"克拉玛依市","childNum":2}},{"id":"650400","type":"Feature","geometry":{"type":"Polygon","coordinates":["@@J@HDADDBDFFBF@DBNAHBJ@VEDEFAXDDAHBHADDTCBD@DFDL@BALAHFPBF@NFREFEBEAC^AJ@DABALBJC@CHABABEHABCLABAJCFDBDDDHAFBDABAF@DCH@DDFBFFDBLBN@FD@AL@HKLCBIC@@CJINBVFR@HCDCFADIhJN@LBLANBJANMJELAJBFAPDJJL@JA`LDCBEDGHCCC@AC@CEeMBAAABC@GBABA@ABAAC@A@AFAACBEJEBKLGPIPEDE`GME@ACCACJ@DC@IFKACBGHAFADCDIHGF@HCAA@CIGECI@GSAEBGHAJKLC@EBAJACEBARG`CNBACBCCEDC@CGACAACC@@EDA@GCEECACNCBIDAACBIãFUJULa@MBEFKNOBYōœCWIMAYBWAEVWAEFOAYHKDC@CCGJQ@C@Ek±Cg@ILyJQPQHQFYB[AyD]J[R]DIBSAaAsbĩRyAmCUK[@EZOFIJOLKJEFGJSDAx]NANEZGPIJG\\IRGLGfIRITOPuBOCMEEECKO@U\\IH@^I~APIPMdsP]FMXZyDELIPMBICWLSTQFMDC@CDCCIBEACBKHKDKAEFIACDCBGJM@GBGNMBGHIBYJKJOHIBEFC@EAGDE@G@CDCBEDEHM@AAIDCG]IEGI@CDA@IQGAGAEAICEGAGB@ADKDCBOAGAMBOCYDUHOMM@E@GGMDK@MCACACAJQ@CUI_ISIACFCGCAICCAIDABEACBCAEJOCKDGAIDEPCHGRAH@R@JCDGDMLKDQTODGFMTOZIHEAICMBGTQDGAKFCDAZAJKDK@IEKEQ@CFEGEBUBGD_BEHKHOGYCGCKH]EKsH{Li@MgEsKW¯e{Qó[¥K«QsDYFSDµDgLOFyBuHcBJ}T_J·VAwGQA[CGB[@SAE@CDC@SEYE_ACAKIICSEMAQ@UFSD_GQ@WCmDCuFSFoFeJEĩZ{CQS@[AQDIDS@ICO@WKG@ID]BSAgDYAMDUHwB_Be@cAEBI@GDG@{AOFO@ÇHęÜ[ZQL[NKHVaD[FS@YFWA]DUGcM[YMGKAIDSGSEW@iLWV]Lc@UWIHIB_DO@KGKCMAWDMDQFaD]HMCACACAUF[CI@GDE@cACBCDFHER[HoBSDGF@LCFIDUHSB_EGBODAFABM@G@AC@OCKqFSDMCWBYGGIUGKBO@MAGIAEQEOBSSOAcFMHGLGBMHABCBSBSAM@CBABBDJJA@ODqXQLMDuHOFQD_LIFg@GCCCEGKAi@YD±FCshABUA[BWJOBMDEF@TCDIFwJUFeCa@BWBOGGFYASDI@EDIDS@KEO@IEA@SHGBE@IEECIEgBiCGDCAABWAKQU@MEIDGJQFQEBKJGCGDGAAJEJMB@BBB@DEBIAEJoNQBK@E@ABE@AB@HFBAHABGBEFIDAFBDRHLDXH@BED@BFBHABBJF@DF@FJADBB@DEHFBBFED@HANKXHVAJDDHLDHFJOVGNELAD@JCDHZFFAHJVC\\B~@xAPGfINqtYbKLMHYNqViX]`c|ALBFCBAJ@BGFBHDHC@ECG@EHEBKTILCN@DEHBHCT@FABKBED@FEJIJCJAFCDAFŝÂCDMfgjcl}¢GPQxEVBTCDKHERJHJDTLFPDFHF\\RtZHD\\FØpfRZNFF@HLHCH@LP@BJHPLJ@JONFPBBN@FFRH\\FB@LPCH@JEJCBAFFBHARHDDBHBHDHFNFXWPGRIBQ@ABFJADG\\GPURQLeTyL]HMFQLODMJMFaFQLAHGJWJSJILA@GJCBuGW@@BBLAJKN[DKAOHILCJ@HBHBL@LBHAFGNQPIFADOFCFAJCDUFAHAFg`AB@HADGDFJA@oG_DGDEBKAYIWCW@WDYHKAOCOFKAUIEASDiL]D[CYDSBQDQLE@I@KEGAOBOFWA_JUHQJ@HHBVTN^RTHTBJABWHWLW@_BADBBhAVFWHO@C@EEK@ONDDFCHACC@AH@FFABF@@DFCR@@@@DNINAHVLTEZAHLJJ@HGRATGJ@XJ`ClGDBPFZDvAdETGLAVBBFAFFBTC\\MJADBHFTDVQHINGBCRMNIFAT@D@HGBIDCNEFCLC\\MRQNERMD@JJHDHCVDEBBHFADKJSdQJ[VyROBGBIDi`adSPuLGFSLOXONIFaJMFVUJGBgFMFQDCBUHDNBLCN@JALENIF_JI@YEQDIDQRYNMDMBEDGPSDodiVQB]GI@QNGDI@GDI@MGUAIBEFEDGFM@KAADCPDZCXBVENRPAFFPAHGJAHGJ@PBJCPBB@FABBFCPAJKRCFCDAFKR@NFNH@N@NADAHALJFAFCDGLA\\FL@ZQHALBNAVFJ@DAFABCBA\\@HF\\EPBHAD@@DL@XGZBNBDA@GHCRBR@pFLDbAXJFFRJNEb@DCPBHDHH@FEB@BBJD@FEPBLDR@LFX@XLNGZAbHpCRBJBRJNADCRAJ@^DFCJBFAbDPD\\JZ@`DvJJAHGPMPCHDZPZJbFL@NCF@JDLBDCD@THPDR@RBHDHBNAH@DBDLFARIH@LDF@NDH@JARCF@JFPMN@P@ZBJCDCAAGA@AFECWIGGMCO@ODK\\g^wNE\\AZEJ@XIZ@FBBDBPDBDBJ@RCD@FJT@JAbS^QPETCXIPCVBdRVFLNPPFZFDHHHD`JLHHBVPPTBJ@FCHGD@DBDAD@FFFAJDFEFBBANBFFFABAHEF@LCDFDBHEF@BDBLHJCFBLCB@BEF@DEFAN@FDF@BDCF@BRGF@JDDFFDRDFA@EJBBCHAH@DDFCH@FAT@NABDCJNDJHJBBBPFB@AHPBFA\\FJFJFBFFBZ@FAJ@DBL@DBBCD@JLFBHH@FFBBDHADAL@FB\\@NCL@JAN@jC^EBDFDFFPJDF@FHBLLFBJBNHVDFDJBJFNBRBJFBDFFAH@FFNCLJDBDAJDPAFBJAL@JJLHLLHJTAHFDFNDD@HFFBHDBDDHRABAFEF@DUNCFCJED@BHT@LEJUTABEFAHGDCFFHAHDDR@LANSXEN@PGJAL@DIFCZB^HLEFEDATCN@NI^EFANBJJJB^EF@NFF@PCPBVAJCH@LEHANGTIJGBCCC@IBEXIHK@CEIBEGQTGDQPCJ@HDJHRBBBDJBDJBNFJRPAFBHAHBHEJCXOZCBA@GBEAEJEHEBMHMCKPEFAR@LEL@PCJ@LCDICC@EBE@GDGBKJEFANCDKFGJBHJDBJ@FAR@JCHIPDRCP@JDRCNBHLJADBLATIFBV@TIDELBJCRQLBLDHANAFABCDARCXBtAREVCFCH@DDJBCI@G^CH@HCD@FJLFCF@D@BFBHARBFAFAFEBELCD@FJF@NCB@DD@FDDLCFBDFADEF@DDDFDALRVBJCFBDNANKHCNLH@FFFC@AN@B@@CDALFHCL@JBAD@BJDHADCTAFBHJDBP@RAX@BD\\EH@\\MLEFG^BBNLDpXBFAD@JEBBDGDBBF@FFHCFBHCF@TEZFZDBHCD@FDHCFCFDJDDMH@DBBL@RBFCJADBHHNBJHDAAEDCHKL@JDJADBJJ@FNAbLBAHGNC@B@DBBDLPDDFJFHBLAT@HDHHVFD@FCHQRCPANIJALBLJH@`AHBNGP@JGP@NOHAHGN@LCHIH@FCTKF@BFDD@BDBTDTAbFPIFEAINGLADBHNABBBNDBDJFFH`PN@HCF@BABA@IBAH@JFNBLFFEFKFCP@LBH@JAJERAFCPBTFH@DF@D@BPCLFD@DA@CNI@EECAEJAPAFDP@XHFCJBHALBJAB@@EHAP@LFPAFDHHD@TDRAJDHFJBDJHBHDF@JEPEFBFDF@JGDB^@RDVCDDD@HA"],"encodeOffsets":[[92938,44563]]},"properties":{"cp":[89.184078,42.947613],"name":"吐鲁番市","childNum":1}},{"id":"650500","type":"Feature","geometry":{"type":"Polygon","coordinates":[],"encodeOffsets":[]},"properties":{"cp":[93.51316,42.833248],"name":"哈密市","childNum":0}},{"id":"652300","type":"Feature","geometry":{"type":"MultiPolygon","coordinates":[["@@ZSL@PENIhK^OfUPKNMDO@g\\}fNYCoKUvLpQnUhEMwdYCItD®PXHjV^DSzNfD\\GfFbOtQAODKLUdavERCVaÎMrA\\O^K\\IZHC\\t``Zh@pg`WZkPGVEIAIECECK@aGXKFCFIDMFG@EHE`i@CGCDOHIBILIJMAc@IBCAUBGFIPKBGGKIIGK@CBGAI[_EBGFKBcQBC@CGIUGûÓgsFIBK@CAGBQDIFEBGDCCCBEEGBAACBIFKBMDOAIDÏYGEqC¯M]o_µxµdBCDēAKCKM¥YNIJBJIHAHGFADC@EHGGCHABEJADCB@FGAA@AFAF@@CF@DCJSVIH@FA@CFC@AHEAAFADENEF@HCBEJBFCDABKNERSLE@CLEPA@CLGNCTOhSDAAEN@LA@GJCCCAKDEFABC@QJSAKFSDCLQHEJSPUDKXQCM@IDG@MOEAEECIA@EECE@CCMEM@OCCAEBEBQAQBGCI@CAeEGCG@IBYIKBcAICO@GCEAKDIAKDGGGAAAIANCRGR@bIhSPBJARCNGHAAA@@LAFAL@JI@EFEACAEDABAFBBCH@F@BCHA@CBADBFETAHBLAPBRCJAJCDBFCD@GEEBMAW@_EAGIAECIBICAAIEGII@QEBGFK@EU@UC[MWCGAGAQIQAMAcAEBABUAGHGBQCSAS@I@CAG@@GMC@CMAEEFM@CICDGECBCFEE@KGBADA@AKCIBEA]FK@ACA@KDQGBECAEBCACAMFGAACEAEE@AEE@CK@AAGAIHKAA@CEEAaCCACA@CGEAEBAD@DCGKJM@E_KIBK@IIOCEBIAKBIFMNGBOAKBKAM@gICJEBCDGDQ@UEMAIJ@DD@AJKDGLK@@BECM@KACAEEEACCG@CDE@ABCBEAGBCCACECIDABKBADGBAFABGB@DIDKAABCBI@]BBDAFEFQFMEE@OAGEKBABK@EC@CACSDCCGBGACBWCEBCFUFI@GAMBCAE@EACECABCGCG@IBC@CCUDQC]@CAIHE@ECEAOFIFE@GCIAAIIAGEGCSBKAKAGGECOBKEK@KB@FA@IBKAGBIAEDEAQEO@ECQBGBBFFD@FMJ@DCBC@KEOD@A@CCEG@SEOAEDQBIFIBG@KAO@EDELEFKEMAIEG@AB@JABABE@GDM@_OEGIEACMCAABAGMCAKBMHBJEFOJaESBSCCA@ACCAEE@SLEDG@GJKDM@GHGBMPO@IHO@MHGA_BG@KIKAIBMJOBQDGREDC@UEGGGCS@KBGAIECEOCCKAA@C@AMDGHABaKMB@EIICAIBICK@GLCDBFCBIGMAGGCAIBEDQAK@AA@CNGCCCIDEDECG@EDCAGYCYESFE@GDEAGDEEE@AAHCACFA@IBCAEoWKCAM]AEHKF[NG@[FACW@QBO@CAGIEASBCDGBIC@ABCIAK@GDKECB@DA@M@@BEDEEG@MKGDMLMBACDEAIQUBKECCC@CFEBCCEEAKDCC@ECCA@MDE@EIC@KDAFEFEBEBQAGBEA@A@CDEKEGIA@GDG@]D@HDJIACCG@EDUDQFsBWAQDCBADEBMBGBKCKAQRIDKACFSJU@EASJKBCAIBGKMAQDICO@QDOCGJIDQ@EBI@CAGIIAEHCLMDEBIFALCH@HAF@FDDCJKDI@ODK@KFQ@EBOFDLGNALGHIFBFAF@HCDWBWPIDGFGAGBEAOBIQMEIAACCIAAQAIGGCI@ODCRSHHRAFFJ@DGLWJAF@JDDADIHSJMHGBKFG@IDUBOAODE@MEE@]FIAIIMAEB]FMJM@SDCBEFKF]GYAEDCJQBSHM@QDEBMTKBQ@ID@BBJADKDQ@GFEBCB@LGNCLDNAJADKBMEGB[XAHODABADMFDJABGDCDOAI@@LEFG@QE[FIGO@QMOBGCG@SEC@ADCBMBO@UHIGC@MCU@CDBLCLBBTDDDLJALFJ@BGBWDIFIFGNGBGAG@GDIHCBE@MKE@CBCFIDIFWGMBODAFBJEDIJILIFAFAFBNUEI@MBEDGEICOBIHE@O@EEO@INAFDFHH@HDJAFCDSFEDEPBRGJKGG@SKCECMACKICO@CCEIIMGQEK@KBOFECCEOIMIIIEAMBIHODoB_A[HMEWMKACF@NABGBAD@HHH@HCFED]LEFIBGAEIQUG@GHA@I@CACGBEAEECBCHCFGFGDMKIIKQKEGCCGFO@KDK@AC@OECEBCBIJCBWD[JECAEDI@CEAG@QDIASEDVDBDHCJDF@FED@DAB@LABAFEPCVUFEBEAIFKC@CCAG@CCAEM@ELMDCF@FCD@DCBDDIJ@TADAAADEBADEBEBU@IDEDABIFCFOFCFID@FBBAD@FIJAHBJ@DJJLDBBAHEDCFBHCJCH@LFBBBKP@DGJMNAJEB@F@DGHAHCFBFAFDJDD@FCHGFAF_N_CCB@BKDCDOJGBGHIBOJcZQJMHEDCB_RAFCDBHCBAHCDBNAJBDENE@GFYBE@GHEHELAJ@B§KĜEÂkBN`RzƬҰ`ሞADDILDJAHBDJDIHBFMHEVBHGTEH@FPNTTXNBTPRDRFLFRLXL^ZljdLN~r\\`JNVfBD@HDDAHDFRRLPPPVZJPrzHLJJv|DFBBJNN^ƪÊ"],["@@I@_vW`AH±`AEFUDGKIFGVi¯@@VMBEFE@ECA@ÁLQ@EOLIXCFERABGHBPIEUBEFEFA@AFEGEDG@CBAHBBAIGHIDCJFFABCCCAIEA@CDAH@H@BAAEE@DALCACCCCB@DCAAA@CBCHGHCDCBOJWDEEKDG@EIIBC@O]OAG@EDG@C@[@CBECK@CFCMGBED@@AIIBCACH@AE@AJCvaxiHIICAAK@CA@AFCEA@BAABCFBCGG@@ABACK\\Id_TUFA@EC@FIAA@CBAF@BGA@AAHCAAB@@CCB@ADCGA@AD@@ACCFQ@GAIEAEG@AHAIIBAD@DCCAGACCCFA@AABEHAACAAF@@AAEA@@IAACACEFEAC\\WKMMODOGGMUIICAXSJIAEBA@EKggZKB@CcBAADACC@EIKC@AAG@EDIGMAKGUG@@DEE@CAGCAEG@GBEAACC@EBACKDEAOQKCCC@CMEGIEGDEKIGAACA@AEGCF@ACKAEAECEASMCCAGEEACEEGKCCIAGCAEICIKKQEGEKCIEC@EECBC@GBIAKJMDODC@GFCBIBCBKFICG@CBG@GBIACDG@IACDECKBCACBK@EEEDCBCECE@ACBADDDACCBAEEE@AACEAAAGKICEC@BAGC@EEA@AC@@CCCIG@CGGEICAOOCGECAIIMCQCEACCCACCCCCCQECECCAOEEEE@CEICCCEAEE@EECAEEC@CEAGGEG@CEEEAAGCE@CGGAACGACIIIMKIEIACIGIKWMGAGCEEE@KIGACCMAMGIGCEGGGA@AMEACIAACIAGGEA@AEA@AIEAECAIICWCE@GIIACCC@ECA@EEECC@EECBEAEBCACIECBC@ABCAA@BEGC@CKBEGG@AASCAGAAICAGIIECIC@ACCCECCE@AEKEBEAC@ACG@CBC@ABCAGBGBCACHI@EDAHAFCF@DEVINIDKB@BE_eCKCO@IDKWU[SACLQCSA[AAACEA]@EE@K@ICGMOGEIICaCIGGIAOICEBC@CEIICEEUKAOTCFAJCBAHENCDQACOIeGCCAOAECEMCGECEAEACOEUC[IaEQAWF[NKLaHOEOOIE[KYCWHYTKFuPwJFgJ@FIHSASDMLOVADCFGBGAEBCB@BABAFCBI@ADCBCFQLCFOPGFILOLIJED]TGDcFCBWFeNQ@E@GDIDI@IAMBWNGBGFBHCDDJCHGFG@ULADADIHGDU@WDUHQF]BWLQFGDCFALJRAHIDKHBHFLAVEFqLKDAHFN@DCJWLELQFGFCDAVCN@VE@KEIBCEMEG@GIMGG@UDAA@EUEIGGBKJKHE@ACEACKOIK@EBMLKAIFQBAB@FADGFO@IBEDGLGCUACBONMAIHK@GDGAMFG@IFQKYCGDYFMJ]HE@KCSBCFEBCHIFAD]FYNKBQJMDEHMEK@OHKCE@IDCDGFGDGFAHOLGJCJIBENE@ECS@GDMBGCIDUIM@WFFHJ@FJMFA@BDABOBCDJREL@BFDDHLJBHJDHCNBBBBHBDRADHCJBBRJHJFDFHNDDDAFBFL@HJJFDBADVDLCDCF@XADBFBFDDNLDLLCF@FHFAFBBBDCF@HCJFHDHEFAHNJDJLJAHFJDRADGDBFFDBLFDEFBBP@JEDBBBEHHDCH@BJ@FBCD@D@BJH@FBBHBJHF@DFAJBFABAHBBCLIFELDN@HBFHADBBLABBDADDBHBBDDBCHDB@NBB@LHFLFCDBDDBFABDLADBBDAB@DFFHHNFDB@LFD@FFHBBF@FDBBEDBDHHH@BDDBHADDFDDFHBBDFBDHN@BBDF@FHBFFF@DBJ@DFFBHFB@ACDAFBFHJADDFAD@BBABGBBBAFAJBJALBBDABIDCHGDAHFFAF@HCBE@GBEJNFAFDDBDCFDFBHCFBDJD@FDHJDCF@BNN|hfbHHLFHHDJbjPZbXHLZXT^PNFL@PGJALBFVZJ\\DPAHCR@HETBJDB@DAJBREVDVBDJJDF@HFFHPATDJBTSpAFBHAJ@HGTA\\@RAL@VMTEPAFJVVZBJGFI@IJEDM@@HE@CCEMA@GF@FCFEB@HBDOL@DJFBDIJCFEHCHBJILBDAPBJADIHAD@BFJKR@B@HDDJFBF@FFJADQLAD@DCH@BD@DCDADDAJCDG@[EEHCA@CCACD@FE@CEDEAECAIFIA@FFBAHCBKCC@AD@BADGBGH@DLFDFG@KC@DHD@BCBICCACFAHUHG@GBADBDDA@ED@D@FDAFIC@BBHC@GGG@AFA@@CC@EDGDAA@ABCEAIB@HADBFALDDDCB@BDAFMDED@DK@CDAFADEA@CGB@BBBJBJD@FADAACEE@AJBBB@TBEDIBCDE@BJIJEBKIEB@DB@HBBJHDBD@BCBEEGB@@FDGHCC@ECBADCBACFA@AEBADDH@DIDABHBDADCF@FDBBKLECA@BDCBBBAPKFnK^KLSVeZUTGTAXAHM^SZ_Xo\\MLW\\KHQJQDKDħG@ÌDʒCtC\\BLARېB܌C@ˡ¼ùƄȯvÓECCGA@BAA@BGC@BCCABAAA@EDCDKCA@ADELQJG@GDG@CDCAM"]],"encodeOffsets":[[[92848,46580]],[[89694,45603]]]},"properties":{"cp":[87.304012,44.014577],"name":"昌吉回族自治州","childNum":2}},{"id":"652700","type":"Feature","geometry":{"type":"MultiPolygon","coordinates":[["@@PAÜph^PCTMTKDI\\Wl]gB@DAFGGI@ECC@AK@UAWK]GUKIKIGMOKUYuCG@OGMBSSBMJCH]ZKFIHCFYZGB@BÑaƅ»dHn_D½ÞzFbPDPTBafW[KpIY"],["@@EKOIMCMMkYSFyeGBGmVCCICADAVEFNLAFJdIPpZ@NPFABBFA@CDCNCXAP@PPdRJFX@JBFDJFJJtKPG`IPBHAFCBCLED@LCHCHDFAAHF@DCF@BCFADDhDFDLCJ@@A@CDADB@BBBF@DCJ@FDF@BCB@BDF@JHNAFBF@BD@BDDF@BFB@N@DDBFABBBFA@DDBLAAGBAHBDFFA@DABH@FABEG@DCCC@CDAJBFAADHBF@FB@DC@ADDDFDH@BAF@B@@DHBBDD@BAAEH@H@DAF@BCDGD@D@BFF@BCFCLADB@DD@BAF@BHAFAD@@AHE@ECC@EF@DDBD@B@ADBB@FBDFBFADDF@DAAEBAHBFDHCD@DFDADBCDCAEFBBJBBFF@BAD@DFH@F@DFB@BADAHD@BA@BDJ@@DDBF@DB@DJBBBBBED@FDHJBDCLHFADHG@BDBBDAHF@DDBB@DC@DA@BBD@HBDBBDGDDBDAFBF@HDPF@FDBDDC@ABBBBADB@DED@BLDBDBFCFHFJAJF@@PBBFADDD@FCBBBFBFCNH@BGDBDRFD@HDHAFDDCFDCBDHFA@BBBBDADBD@DEBCAADLB@DE@@JFBDEDB@BGF@DF@@BGF@DDBm@_DKDWHCFCDAZCFIDAFBBGD@FFDFH@BIVE\\ITCHOPUfEHAJKPCHKPONILAFUHGJGLEPBHARHN@PDHZvLVPRHFJLVL^HXLVBL@@BDD@FHJCFEDNQsvSt_¨e¤]dO|Sük´WĦeG|CHCJDPADBD@DA@ASlApBTBfCVGDEDKJEJAPCFGFC@A@AIID@BCDCH@BADA@CHCBBBDDBFAJBDA@CAA@@FAJ@BCHDD@F@@AJADC@@DA@AA@BAJDFCDBJC@@ABLABBB@FABEBBBCDA@AFGBEF@D@FCFAFC@EFCACDIEK@AJ@@AD@FAD@NFFABCF@FCH@F@ABB@H@F@D@BCHABADBHA@DB@D@ACBAHBBCDB@B@BDAB@@AAA@AHCE@BADADBHAFCBCBBD@@AEA@CH@@EDCBEJCBEBEHGF@@CFEGCD@D@DA@CAC@EDCHCBCACDGFCBGJEAC@ABAHB@CACB@LCEEFED@AAE@@A@AFBBACCFCHB@CE@@@EAB@DAD@BA@CFABAF@BAA@BAB@BDJCCCCBAA@EDANADB@BHAAAC@BABBFA@DBAAAB@DDHA@ACAFA@AI@BCD@@ADA@ABAHA@BB@BCB@BED@BA@BD@ABD@BACA@CHD@CC@BEL@BAC@BABB@BDAACA@ACB@BKDYEOCSWiUmAQI[KiGkAk@SEWM_DCHAbUNEFKDCJAFGHGBIACBCAGFG@EHI@EGMAK@[IyDíXEBMOG@KCQASE[BKAu@SAwLEWDUDCBIFIN[DIAECCKIUSGICOGGGAIIGICIAIAEDQHE@ECEUQEGDCPKBEEECACB@ACACACCBEEACEG@CEMCCGKCCCIAEEDGAAGEFIBKLIDIMESBECMCAAJIJALODOAGK[QSOUGS@QDINQhgL]DoBOAKBO\\IDA@IAC@WJAHIACBCEG@CCCGCEGUKGAEEGAIBIC@C@CFGCEMFGBGCECC@CFIBEDAFcGeECOBMBs^IJKPULIAKDGAK@GDFDDHLLC@GNBPAFQFKHIBEDQCS@GAK@MCUJI@EDQBoNQBe@_AyEGkHOFICO@CCCAAOEEIGG@GDC@CDWNOAIG@GCCAGICG@CB@DI@ECCGGAACBCKKMBIDKEEHCHBHCBMBIDSEIBEDKDEDEAM@CDIDOAMCM@SHAFID@BGHKCAECAIAGBGAMIAAI@MBIEA@MBGFIE[CGFGACDADCD@HANDJAFCDGDIJGDCFCHKB_NWHSAWHgDQDIDWBKHKBIHGBGHWNKAOJC@CCEBA@CBIDMACBEFSHEFQD[@KHWHMRQL@NCDEHADMDGBUD@DIHEJGL@NELMFK@KFEHBFEDGJG@CAMACC@CGCUBOEM@GDAAKEO@KEOAEBKJWDKBOA]CGBM@YDCDM@Q@OFM@MBIAGDaXKB}JyRSBI@WCOEM@QCGDE@GDSHG@WCWDGBTiHqHSFkPGFABGHK@ECIBECU@IFADAFMDA@@CC@I@AHCBIDG@GB@B@FEBMC@DABCDGBQGKGEBCBE@GBABBFCJDB@DBDdTPBFBPR@NHDRZTNBFBDNJHDLJLTFDHBLDRANDFAH@^GL@FBRCdJR@HFHBFDP@HCV@NFNAFDLBP@\\FN@@BABIBI@CBCHEB@FIJMNMFABDFpPXNtFVNRANBFF^HHF@JCHGL@FGL@FBD@PBBFALCDBNEBDIJFDBJG@IFIJKAS@CAIFEDEAMCEBMCI@IDECOBGCGDI@CBQBGCKAACC@@JEDQJCHKBADAFED@HDDDBFFHN@DDFH^JNABCNEDEABF@DM@EGGICBCF@HCHMDOM@CIG@@AFABUBOAHNRXBHJJHR@FTJBDDD@DNJ\\NAFBNONB@PFPBLBHDL@LDNBNJXHDCAGBEACDE@EBCâJU^JABLBOTbBHANcgDeKT]bµ"],["@@FG@AVMHHDBDCD@@BDB@DBDAFCJKNqVÃ°¾Xzi^IDGT@rGFARE@ALIXIF@FCF@DDZI@EBAF@AAFCBBABBBFABA@AD@BA@@DDD@ACDABDBCAAFAACB@ACJADBDABCCCBAJ@HBAAA@AADAHBDABDBA@CD@NCBDNBDBDABBB@DCF@@@DCH@BABAFABCD@DCAAB@D@LGB@DCDBHA@AN@BANAFBLAJDBAJ@HBF[QBHYE@@CBCDB@BD@AA@ADBACEAAC@EAABCA@C@CA@CFED@FDF@BG@@DMACE@ABC@@CCAC@GBEDADA@IEC@CHADE@CBG@G@BD@DE@ACGA@CA@E@ABG@ECCCBCD@@CEAE@GABCA@CBIACB@DDDCDH@AFEBG@BA@CEBCEGAABBHKBCA@CEBAABAAECCM@A@AEE@CC@AACE@EAMBIGE@ACA@ADE@GCG@CDB@@BKF@FQDEAEBQ@CD@BEABBABCHADCB@BAACBCAGDA@@AW_AAHC@BFBBAF@F@ACLCFBHAK@CCE@AFE@CDE@BGEBGCGDKDC@KFADEDGBOA_JOHsLIIIECAGAAJ@ARh"],["@@¤MlA@FCDVLDDEHBBA@@BA@BD@@DBCBFFCB@BADD@CBB@ABC@DBBBC@BBA@@AA@@DDBCBBBGD@DCDB@CDBDAB@BA@EFEJFFHLØƐm`¾Òb@AHAZYDEJGLE^YDGNITA@IDKHKHIVGBEJKPMLODILMBIFGVeLK]AOWOCñwB@gUCBùfcWGC@CkGkSHQNcTMDYL]DGAcHG@MCEBcBSF_z"],["@@TKBBDAHEFDB@JGBDFHEJD@BEBADBJB@AXCABB@DAB@AFBABCF@\\i@KJYtABGhAjE`yEMIIUFYBaLADE@ACGB@AE@MBHGJYF@BFRC@M@@p@@BSAABCqeWLUDSLIBIKLGeUbVFCF@DA@FHLBHDF@DEBEFLC®YÄ¯QDXcHMgAFYB_N@HMC@ND@BDQHERGAFIia¶rPDBDL@HMdBDD@BFIBEIaAaKáAD@FCFBDAFBHCDWGMIMAKCK@GCKAOAOEA@PMAMBE[MMI@CCCACSI@EGQIIAGQWGMPBVABABE@@JH@DPNNCDG@GDEDAHJFHN@@CAEFBFCDMABIMG]CE@CGMEECACC@GFCBEBCLADGRIFC@ID@BDLBHDRADAJ@HCHDPAFDJCJ@NDFANDFBFCJEDBT@LBJIJEH@AIECJIACMFCAKDEBAA@OAC@EHK@EHKDG@IGE]GEEMAQBUMsEWMoOCEBANENMJI@EFADGDAJ@JABA@AM@[EO@KAECMBMEU@GDO@ECGAGEQ@cIQDEAK@]HG@EBMCQBKCGAECKSKIGCMIACAESMQYGC@MOQEAOAcSAC@CCADIAEBAM@MJAFBBABDJE@ADEBGAEBIAGDE@AFILJDKDADBFABLFDHABI@EBIB[CU@MEGIODK@DHCDFFBJGBCFG@GBK@CHKDEHBJHBGFEBGFE@WCQ@@@@EEAAIC@GD]@AB@DBFIDUBMCMFE@IJSAMJY@MEO@EA@DMBCDSJGFAHEDKIG@QDSGEEKAK@MDCFKDIA@DE@GBACGFIBAACBEACCUE@AC@@CC@GBGHKDiJ[CKDCEO@E@CDEAEDWFYEIFI@MFM@GAEDM@WDABCJAB_BSFEH@BDBADKHWFMJKDEAGCG@GHQFCFYHcBIAGBM@IBGAKEGCGBEBIACDMB@BADMBEDMCC@IFCNKBEBCFFD@DABCFKFUDKAGDOEiBAFA@WMOHODSCACM@GKMBABFFAFGD@FCDBB@DIHDFON@FABOA]FEDI@EHSBSHCD@DC@EHEBO@MJSBCDE@AJOHEHE@KAIFEFMCEEE@KCIBEFC@OCE@QGKHADBDCBSHEDC@@JK@IHSBCBADAHDJHDL@LFBFJFBNJHALBDHFAHQDKHEBGFBFD@EJ@HEJIFKDM@OJG@@B@DFJAD@HGNSEM@EBGFKDIAIKCAICE@QDJqHJSF_\\IDKDIBMD_FmL[LQJEFEB@DIL@DAFIBKFED@FLHCFEHSBMA_KMAM@EDMHCFDFJDBD@BGFMDCHEBUBKFIBICECKA@C_QKEaAc@G@CDSHO^KDQGI]ySMEWDa@cEMEsOS@SESGQEKJDLDLDRCJKNMH^GN@ThXaN_F_PSBaCIFEPBJNJ`NNL^FZPBXLP|NXLJNXNbJPJ\\XRLBLHRTNjNLRNJP@rWLH@LFPbERMtebADVFbljTXFhFLCNQFKNOPKJAH\\JHJRLTLPLRLDHBFA\\VT\\RVLZJHC^[NEHML@THTJdD|PNF\\DlRrdYXGNVFTGpaXGZ@hB\\A\\IXKJIJITI@PHXPTTRXdFZJlKpA\\B\\NhNZDTJNZNFTDHFH^JFd@VGXO\\BFJDZJFNDlJ\\AFDHNPDNEPG\\ETATD|`\\N`DR@\\AbIFDJRRN^L\\FVAHGDMLM\\AXFPDXLNJPDX@PHFNDLFLLFVBn@DPAZLPVbVVBlIVBNJ^RPBbKPAFLlV\\CLFJFP@@CBAHKFEJETQ@CACBCROHMNIFIBIAILMLADCAGPEFAJOXONEFCNODGLKHMNKHQLIFINDXBbHl@`CXD`RRCrRPBXEh@FGGwRKTIdDTLVH\\F¾ÝYqr@¼c@GSIICOI@QB@@CFCCK@ALGFEFIACBAAABCBGAGEACGECKMDAAABA×@HSBCN¯ÙH[GIUGI_FKAI@FMJQ@ELKLITCFID@B@@EFE@ADADEREFBBHAHADEF@H"]],"encodeOffsets":[[[84459,46267]],[[84145,45787]],[[84253,45818]],[[84102,46004]],[[83958,46058]]]},"properties":{"cp":[82.074778,44.903258],"name":"博尔塔拉蒙古自治州","childNum":5}},{"id":"652800","type":"Feature","geometry":{"type":"MultiPolygon","coordinates":[["@@eNYHGMū|Jn@vFJAFGHAFBFDF@FFJDDNBPHDJPJD@HCNARDJDEHDFELCN@DHJJFDFJBBBPTAHCDELKDHjDBBF@LCNFFCD@XILMHGHQBCDGJ@HOLGNIDEBQCSIG@@XBHGNBJCJANDZFNBBBDANBH[@]AQAOAGBYLICMIIC]CO@QDoVgVIBC@MIICkAODGHEDMAGBOAMEMAI@IFSPQBMFCAQJ[R[JmVUPgTTSBMCMMCO@OCOIKOGoMQIWISAWFBJBD@FBBBFAHCFSPAFDPHN@Fa@MACBSLX]F{B_HqH_NkV[LaJmTaLwFiFeJDÉCmEwI]I_IYAYHONu^]FaHgfYR[BUAUDMLWNWFkAcB]AGBQBQJOJc\\@DWJ}SM@QFYAUBPO@]IS@SHKHKASE[B[DYBiFgGIMFO@OKIW@cNIBOC]SUCYBYE_OOCs@UEYK_QQESA[DWFu`SB_AUBYLkFIDSL@TDVBVGNKJAHILOJSFQEYKIIO@MHQNgN[RSDS@k@cMUMSEmCWCaIQG[EMD]VG@EFYLQPUJODINGPGLILMNWNUDWBOEQGSM@SDKCGOGiGSGK@KG@IEEKCKAIEM@OBMADXADEB@CMEaBDLPNJNHFFDAFDJHFAJEDCFAHCDI\\CDGBKAUDCAGAMOSSAEACECS@UHM@ECCEKG@OGIGAKDCAEMKAOBWAUBG@EA@CEIECG@WJSBMFADOHIHKT@LNNDFBH@RHL@BADKHCD@BDDCL@HGDOBIH@DDLMR@NGRBNAD_TMNMD@DHFCHIHSFWJCFBX_PGBCDEHEDAFUPMDK@KCIBG@CJGJ@ZGX@RHLVTdBVANHFJALBHEJCJBNHFLHTBL@NEJCXIDCDCJE^CHBHFFBXGdINDNCDBDFBHCV@NDPAJAD@FDBBJFHADLDVGP@ZDLHHVDBVDD@JGHAPKTBPAbIT@NAPAFBHBBF@HFJFDLFXBFBDD@LCNAJBLJDLAXEHGJCHAXPXDFDBFHJFDPCPAHCF@PFF@LAFANAPFRDf@^HNH`NLARORCNDTBLAbKxHITFPNNJRDxB^@^FXVRHDHHAHAJACCFCFBAABCACFCD@FD@LBDJHBFHDHBFDRIZDHDXRHABADEAIDEFCV@NEJ@FCRHAFBDVLDFNBL@FFBBNDZ@DADGLENJAFBBTHD@JFP@LFV@FDJCLCFCRBFAFDPF@FDFHDJ@TFLCFCNABFJDBBN@BFCNBN¾WlLVVPTZLXNPPFPCJCVN\\LZE~Y`CbDV@ZElKZCT@XLdfPHtJV@LCHKFOLAPFHEHCXEHBFAJ@FGFDL@CH@FEF@H^HDDP@DCACBCPCBB@HFDHBHAPFHEDBFEDABETDRFLCFDHLDGF@N@NHJOTFFDBHJ@BBFADFFATDBB@HDDVEH@HBBDBBTFNCNBFDJAHBP@LDXBNGNB\\ADCBCBAV@RFJAR@TMRCBCBEDGGGGE@CDARGDEDADGVANCDGNGBIPMDGHALFBDEFELPNDD@JAFBD@FIZFJCBAJBBFDH@JA\\DLGRCJHT@HDNAJAVDFCJIDAD@FBJAFAPBFAFERLH@FFRFFFJBB@LCD@L@JDTCBDN@JDJGNBF@NFDHB@DBPCFBDBAF@RCF@FCDIAAJABI@OFMBEN@HGDCHIB@FIHSBYAIBWDED@BJBDDHBDFDHRV@NIJQASDCBIBC@CGQAEEA@CXBBH@DB@BCDK@G\\^pN`CFJHHFJHALE`AFHDBBFJHJDFDHDBDJHHDBBPDBDFDPD@HDDADLPDJFDBBDD@DDD@BEBODGDIBABADGDQBCD@HBDCFOBQLKBENHBBD@NEFFNP@@HRJBFNBBBDHAFEFALHDNGVCPIBCFAAEDCLA@IDGREDEJEVABDLCPABBCND@HGN@DFLAJ@JABHLBL@HHR@DEHAJGCI@CF@JBB@@CGCDCHCN@FBBCTOJALBHAPFHCFGHCHANBDBHA@CDGBAHCRAHBH@PHH@HBFFDH@HJDDDFHCDNVFN@FALFF@JDD@DJFH@HAVKL@FFJDNDGJ@DAHJDBDLHFDLADFPH@BCH@BHF@FFDFF@NHJLBBFAFPHJLJHBDAHJDDACCJEBERIN@HBNGZDFAHARGZCZ@HBNA@AAC@MBEHE@CBEJE@CBEEIHADCBBNFL@DBD@DERAJCLBJCFHVHRCJLHBLABKFCNCLBDEVEDCJCFBNJ@NAFBHLJF@RDNGBGFADCI[DK@GCCDGHCLCVAXCDBBDH@H@LETAJB\\CHBNADBbCPBNHDJFDLBFJN@JDHARBADLH@DBD@DCDDRJHPCF@JPHFLFHAPEVD`Gf@N@RCJDEII@EGXEN@VJJCHDNAHCT@FDF@FMJADIHIPKBGHEHCHEDCJCF@LDPGL@NFFGNCRILAZM^EBCJEDGFADETALDF@^GNIZEHCZDRLJEH@NEHBHCL@JGNBPMDAVBHDHKFCJAP@HEBC@EBARAJELBNKFAL@PJDLFBBDF@LGLIHAJHVF@FBBVCH@NHHJH@NFDFJALFF@@UDMBUDCHEREFKXKDI@CEMBGLCrKFEBUEKAGLGJCBGIQBKDEHCREXK^AREVGXCV@HCJGBCBCVKH@HEDGCIDCAGHEHAXMNAJBJ@JCHCF@R@fMXEDAdEHC^SFCJIPKJKHEPODERKDEDABCJ@DABEBA@ADAFAHBHADEBCPUNKTCTBJG@EhIExIvOLEZSXGZD\\LJFPPPFbGLK\\MXEhFhLVDPFD@HMNAVIHAF@DELGHCRAHEBEF@PHJBRCZMJ@NOTFDABC@MFIHIHGJARE\\@VGF@PHRDDCFKHETClMDJDDTDFAJIJOHCP@JBFJHF\\HdRLD@bFBP@PGLAJ@JC^EEPKRDnKHChGZEFEREZWdEnSVEHENQlMPOdSXBZKJ@RMVI`CbKZB\\GXGFGTIBGFGBGCE@AKIBGFYKSGUMBMJ@C@@Q@ED@CE@BAEEG@@BDDGBEDCCPML@FFD@P@XGUEgBAABC`AX@XKXGBAAIGSQSM]USGAWDMDGAGCE@mJAAWcs@[POBGAGCDI@GCGGEQEOAGBQFI@SI[AK@G@WLE@ECSJ_BKAEEGCW@CAOI@SYGGGUBEHAHKJKJYHCAGEagCAWC[@UEkNS@EACGECEAUD]D]Fk@KASOCCBGJIBMLQ@QE]II@IMEUA[HGIFKIMBEJA@E@GEIRIHKHDJABAD@FE@E@EIMKAOBKAECEEUKEEAIEIBGHE@GCAIGHKFCDOFEHEACBE@APCAIGGFEFARE@CDGHICA@EJCJABGFEDGGE@CNEHEJQJAFE^KDO@EAAEAGGE@CIECCEMAEBCFG@AABE@CGCCOCQ@IA[AQCEDGA@HD@F@DD@DHHCHBDJJAFCB@DABDDCFIDIFCACFG@GBEDCCABCCC@C@CEUBICGBEABCE@EEKCKGGAEC@AEACGKEACFE@IEGDKAG_BW@QAIBG@KDEAIEOE]HKDCSAG[[CAAASQIOEOKMIKMG_SEECBAEEGUMa_gWYKXOPA@½JBPGH@PAD@BBJCPBAIHBDEACFA@AFCK@BABAFCJABADABEACBA@BBAAED@BAAAFACAD@ACD@ABFADEA@H@FEFADCB@@A@@BAFA@AFCEAF@@EHAJE@@EA@AJBHACCBACADCCACB@@@AAACBC@AAF@kIE@AGBAGAHQM@IAG[JLD@JCFCBMQA@AQ@AED@FKF@DCJ@BMH@OS@@CGKGQC]OEACSBGaUWCICUCYBB@C@DCAAFEDE@ECME@AGFA@EDE@AAB@CIABNGBDBAHEA@CC@EDIDCBBDCBAAADGAABECBCACDECCDKAOBAFYJQAGTEBQWGSS@GCKEGCCIACABKKCEIEAK@GACBODeIEBCDC@AC@ENOFERECACECMFKLKDK@EIK@CDCCGDOACAAA@EBKNGBC@OGCIGEMBMAACECqKQEC@KDCD@FOBIHDF@FCHGFMDGB_EEEGO@GAKCEIEU@CCvcT±IDSLIDßCE@GCUCMCACGDC@ACAFIFAFBDIDABDBEB@BCA@FDDCBGFAD@DC@ADE@ADC@CDCACBGBA@AAE@A@CJILILGBUAODIFKLOLADBLA@A\\@RFNEF@HCB@D@BGBSJICEBC@GDI@GAG@EAEBECGDQ@KFIHG@GEKAACAAM@EAI@CAE@OCUBI@ECGAQDQAAADICEGEMBG@CBCLIJIPQDIAIBEDKACAIBS@EDIHGBAFK@EAE@ODAD@FBBDBEFBFCDBDF@JLDBBJCJMBCBCDK@ADGAIDAFG@CDIBCDFBADOHE@EBGJI@QJQHGFIBKHCBCDGDE@KHEHGFEBEHUHIHEBEDCBIFE@IDIDGBADIDKFGBABC@EFE@CDI@SJG@@DQFADOHCAGHIBGDC@SFIDWFɑ"],["@@@FCDqXWVeDčtZƑNLɒXEJCTED@HCJAHGDBPGBCRE@CH@TIJ@DCF@FED@BAHALEJCBCHAJCJCF@JEDAFCFAJGVGFGFAHEFGLGF@HCDCDALGJAHERGRIJ@HIFAF@PGBCEADCJADCH@BEJCHBBCL@DCDANADIAICAIKE@ACDCAEFECAAA@EBCRCJBL@BEHAJGFCT@JADBLBFCJAJBRCBAHMLKDIBAH@LAD@FFDF@FCDBBRBRCHBFDJ@VAPDF@DBJ@FBN@BBBDLBHFH@JGLER@HCFDFAFBH@HBJ@HCD@FAFDD@TIHA@A@CDA@GFEEM@QB[B@AKBCPKLKJEPCVBHAJKJKDIB@F@BBB@HADADBDCD@BCF@BCD@@CBCHEDACC@EDB@AFACABAJCACBEJEBEBDD@HCBDNDVDHDF@àDJCTKJC²dSuAGEEWA[GțiEDOHWDEU@KBWFLYAUBQFUJUFc@GCđH"],["@@DEFKLMFKAGBMFKFEBCAECKUSgMU@SD]HQAM@CBKLE@C@QFQBOEEBCHGDGAICMDAAGCAIQGCCIUIeEIQ[MCGOGIICMDGB_EUGWDICQKMCI@QFORQHKFBDFFCDIDM@GJMJEJBDKHSfEHgNWBGFCFMBGDKJGJEBsVuROB]EU@OEKEYF]JGAMEC@MDIHEHMHgHOBuISEIEEGECYAkDQBGAQBcJU@qR[GOAI@EDMJKPGDI@U@kCKDODMAQEG@[DMDKJk\\SNMD_BID]FGBGHIHYHEF@JBDJTJLPLCBOFOHCB[@KD_BI@EHABSBICGACBGBOLEHGXmCYDEFCABIBIDAFCVAHCFE@C@IAGIU@QCM@SGMKMCG@GDIAEU]KKYQ[IQIYGEGIMFMDOFEBA@KDGBCACEG@ECABG@GFI@E@I@@ICGDKFIHK@OFGC@EA@GDCFECSAE@EDE@EBGAGFICKDOCACECIDK@IBGCEBMFCAI@AECAWEGCSDGDE@CHGBECAGGAEBMLMBCBG@IDG@CDCFK@EDIBGDEHE@WBMKIAEBCHC@CAGBAHEFOKMBIHCFIBADABMA]DADGFIBGDKLCHOBeL¯R]LODQLSTmXWVWRQJSLYLWNMN]DO@WHKFE@S@KGWGM@C@QN_hBDHHIBWTIFehIBQOqwCBC@KICDKFcDOISCI@ECGAMGAJEBEFKBKHELIL@FDDEFaDWDQNE@IACBCLIHYPC@GC]LSASAQBSHUB_Va~KJmEmUUEKBUJ_@SOCCM@UKMAKWGEAMHMCC@EEECIKIM@SBKHOJENBBCBUHG@QJ@JJLUNENBDKRMJOFMLOHODOAOFMHyTCJCT@VC\\ELIJMFKNQLOHOFaIOGyIOCOAKBGJWTIJ@ROP]AaAYEQEMA]LOHS@WIGDKE@EF@FCDIFIAGAAmBKHCAE@KEPSHY@QBWAOCQIKSGKc@aLMAaYKIsOQBNsA[ASBO@{EeFIHMCOMSiSOEAC@UHGECEOGaCOCaAC@GDEBM@OCQIOAOBAJEDAACGECEAC@OLGB@MEGCCcES@GACBAFM@GDSDMDKBIE]EaOWAYEkGSAUES@oQSC_MQ@O@_FiNMAYDgAQDOfK`HlEFCBY@OBEDCLCFABE@MEUKWCKEGB[NK@E@AADKACIMAAOCICBCFICCm]SQOG[IQAI@UESA_AQDcCWAUEYSGK_OGQFOEOQGIBQAWDQ@QHKJOBKDWKKGOAIEIAQD[BUFYLQBWS[Q_AMEICMOAEIQM@IDI@MAGCE@CCM@IB@FELIBCBEBAPOJ@DBFGFDFCDSAICCEQACCUCE@GDC@ID_DOBE@CEEDGBcCYCUOEO@ICIIGGAEBIAIDA@CEBGEGFC@AMKG@KFMGQ@C@EFK@C@CAE@ACBKGEBC@AsIUAeGBOHODcCICGIO]OEKFIAYFaPIHMDyYgCQBKAGCGEOUGKIOUQiESBYAiHSAID@A@OACSCEGECWEEE@IA@M@EAY@EACEgCGCEBEAGCBGCEDECEBI@EBE@GDIA@ACIBAABEFKBCACGICEDG@MFEDABIDCLAHG@GAIDGAGAAWAMCIMCI@CAA@CDCACM@GCE@IEGBIGCK@GIEIMACAIAAAIBAAKBCAGBECG@CAE@CEEDCGEBADB@CAAIAAEK@CCG@MI@C@GOOFIAGMGBCJ@BEEG@CCI@CKG@EA@ABAAACBEAAECG@IEMQCGCCIAQHK@ICCACICAGCUECC@CWWIAKEISCCOEGICICCCAOAOMK@CFGBQAeFK@iIO@[CKBiMYFKFKBOAEAAAKGOEGAWDSAKAMEK@OMOG]AMCW@WKEKECECcGECAC@IAAGCESKQOIAWBKACGAIGAUIG@KG@KAMKIAODKCIGGAEBQNIBILUHE@KFGHGH@PCHUHiCWBGDKBIDiBcJG@IFOBKFODWAGAG@CBCHEnCFIHQVSPKDeTcFQJQF@HHH@DCDYBE@kQe@I@A@@AHIBCCEGEMCMCSGmIaOSEQASDUCI@YHK@I@uHMDI@mG{MMGOW[VEFCNEBODEFKTGDGBeHEDCHE^GT@TAJJ ADSRGRMJCJ@HKJANBHAFGNCJBPADEFSFGHADBDLHBDD^@FEN@DDFFDBDGR@DHHADEB@BAHDH@DEFDHEDBFADKLELK@GDELABGB@FHNCNFFPJBBAHIH@HJDBB@FGHIFUAEBIAWDa@G@MDOAIBQJGJCHIHQAOFSBIFAHgDQJOLKBCFAFGB@HIHBDFJEF@FBD@FFNAB]BCB@DOBEFQBADOJ@JEDCNINABK@eHWBIAKDCHCVCFILEJOFEDBH@BSJQ@[DO@OBK@ODQ@GFGBU@EAECIDOAEBC@KAIBO@K@B]BIAKDYGEFK@CFETMLAP@NEfCFKH@BJJLDHL@HFJCF@DMJMFWRCDAJGFKBMECBAD@FFFCJHFADFRALLN@D@DDFADA@CFJLPDJJHBFHALADDLARBJHN@DCLFTAFETIPY`]ZGXIPQBEAIBSFEBEFSHIHENBLCJGBIAYHGHAHKHODQAGBEFCFIHKXSRGFG@MISAIB]HWCQAQJaAIFI@MHCB@FDFGJENC@ULG@EDQ@CDC@CFOFGHCHCBAB@PEBEFBLCDE@C@MFG@YEI@KES@Y@KDIFG@OCGDOVODSPEJOFGJ_LgFGFEHAFD\\JNDJHFDPBFTNBF@ZANEL]fGV@TCH@TAJCHQPAPBBFDDn\\vDDDFLH@FAJBDJHBFEJHN@HDFDH@NAB@D@H@HI\\BJ@LALCH@HKJ@JEDAFADBRINEPADGVGLAJENGJAHKBIDICGF@DDFBLCLDPCFALGFELXRjdNDHDDFtPJDBF@JHRZRFFBTFNBJDLTPHP^FPLFJ@DDDvXJFNPHTP~@RK^ERCH@FBFHJFHFNFXD¬CNGN@LB^FNDJMREHAVKRABKBENA\\BH@JIFBFCBABHNABYJEFBDHLBJADEDDVIFDJ@ZAFMR@PELBNELHRDjDT@HAHObGZI\\cYrÕĦyğäó¶¡zi^|¿ÀDːAʢPˆDtdŖҌЊrzV`DHRNJDNrFÚ¢ӆZƠ@ØG¾I`@TBVOVAFFDFJBDADDH@PATG`FJ^\\T\\BF@DCDCDODKFUNONWdIPIXEXEtAbBbFDlDZCdCNIbKAPB`AN[^KPIROhELGHWHSLKNAJ@JBTH\\@HIDmHMFGHINQf@RD`@lJh@HCJ@LBPJ\\BpJnZ|TZPJVRHJDFLjHTBNALETENALDRPbPhF\\BZAPIL@FCF@VCXGVEFMLCFM^OvUpBdMOjEHMFIHFJAD_X_VBHDFEF@BR\\BH@NCNGJDP@TKNAD@DzP^@`AR@BBVVDH\\VDPAHEBFJ@DQTCJBDAHIP@BDPDH@DQNSFCHCDM@A@ABBJADATCT@LBBPRALFL@NAHIPDJAFARFNNPBJELSZBHHTATVPRE@Cd[PIRIRAHA^BdAlBXEXMNKVCVB\\AZQhebG^Ev]PMZGZB`J^JxJnFÊDCfIjExEbKnSbI\\KlU`MrG`G|A^EWTKDANBb@@EGMCOBETODEBGAEAA@EACAIXETBXJRJpNPHJLDP@PDPNNNDTAShSVOnU\\I\\QRIDBNERATOJEJ@NBNFPBHANBFCHGPClBJDNJD@JAhUpURCP@^DJDNJJDZKHAPBRB^B\\@AGBMACAAEMCYBMDIAIHMAG@WH@TJRDFAJCHMPK@GHIDCRAHGNGJK@WDCEEDM@KAECAGiLCFKDCBGOSAAIACEIEGI@CDMFKCEFGICQCMBGDC@OICIOGMACCEI@ECEAEBEHGBEEI@uImŬ{zSÚcIaGsIKÕkµeSáŐN]ŦHDC½nDBqF^@BDD@CBADDDCBCHDBDBBDADFBODADCBED@HCD@DDFCDCb@RGHGBGN@DCBKLODCDADEDBHdbHND^DDLBFB@JDDRBBHLD@TĒGKmW@AiFCTBA[DCFAlBNHRRHDF@BA@EKEMIBOFAZBJDDBADAB_@ABBD^Fj@@H]@IDCD@DNFVBNAHAFCDKR@ROFAxHBfvB@_ARxȜj\\HXBFDDJBDT@JDFHBL@HHPFFHBXDHANCHEDG@ECEFEHCL@@EDCLCD@RFrLFDBDNBNAHFDJPHD@HALMFAD@BFCPDHCD@DJL@FCLKLELDNDFDBQFEFMP@FBDD@DCFAfJPCDAHBL@FBFJLDALDBJBDDFHDL@HTTXHARSFBHIREZABBPCLDDCFBDADFDBAHBBCBBDAACDAJCFCD@@DFBBGCAHAAMJB@DBA@BCF@FEBBHF@DN@FCFEFBBCDD@A@ZAVDJDXDbVAHDTFB^PRDLHDH@@PTG@ANI@CDE@ELC@BFR@@BRBANEDIDC@IKH\\JBN@GRHBABBHF@lJE@BBD@DABB@B@@DADBCDDBABDDGBIA@BFB@@IFGB@FE@FBED@BEBAB@@@BA@CDEBEFG@B@CFEBBAC@BDC@DBEBBBABC@BFAB@AABBDAFCBABIBEDABABL@ED@BEBBDCFGABJOAIDAAC@OBG@OHIA@¾OBWPZLhXb`VNFHBFDAFF`TNHJLLNFPJPTRBBDB\\\\BHDTLC^GPFJFFBLCH@JARBX@`ABHCLFH@JEFBDLFDHFB@BFDHBLHLDFFF@ADFBHAJDVADFD@D@DDBADDFCHAH@DEDBJEJCDECCBA@CDABEIIACDGGG@CCCE@C@@GHBFCRD\\BJBR@PDDHD@DAFBBH@DEFANBDFFDDJF@HHFBBB@FCP]LEFIBIRGFMF@DHFCHEFAHIBID@FDBGJCH@DQFEBEFHHBJOD@BAFBDGFEFCPEDGLJHDB@HGFAHFJBJFFVLFFFDLBPALBJN@F@FEFC@ABIBGCGLQJFJ@H@FIBAFJNELHJ\\GVBNF@JJJDRBX@FKRANIJAHDDTPLBl@^E^CVCFBFDDHFBT@lMVF\\@XDDBbhHFDBZGLILIBGFGVAHHZH@TPJDBX@HDFFLB`ATIFDF@XKH@L@\\BTJJ@REHAPBRFHFDH@HCJHDHBPA\\Ot@XdBBnIF@HDHBNCXC@GRIVG`IXBPEPAHBLFJ@F@RKRCTAZC\\D^CjKTCFBVJLBPEPDLBZGXCX@XDZJLBFAHC`CpHB@EIHCBC@GBAh_BEBGVEDCBIDEPEBCJEROHMBEAG@KAKAG@GDIJKPGLB\\CLMBIAK@AX@vHDAHIB@JKTIXIHIBGRKbENENIPCRKNE^GzKfSRKVQHOH[BCEIBAR@JAHQXOEWEMCGAGAGCCQGGBEABEDAFI@IDGKOA@[EQGEEM@AAEOPM@IKIGOAIO@@KDGKG@GEEYMeQ×o[EGCsY[QGECEEOSKICIGFQLGDCASFURwHO~¡dkhiNeDCŞÁBEDCBEDIJIFI@EFCLABA@EDSAGFG@CDMJKLSFAFGH@FDD@CGAGHE@ABIDAAEBKd{^_jWrUZMNGLKZadeJILMFQFg@wA}D[IUBGEEGYDC@IBCFKHMPUEICGGKCCBIGULWBM@GFCAEEAFG@CAABCEIE@@CIEAAGBEA@AFC@AWGKCQGAEDEHAFEHABABGEA@IH@BAF@L@RApMFIJBFA@CAA@ANAFIBIHBHCHDLIFAPLBPEHIJCNFV@LRXBBADBHCjDhAJFFDJFF@HATGB@JFP@LFT@JCFCJ@TCZBHEPHXAAb@dDXExIJEDC@SFENCPAXI\\AVBNITOTOD²EZCj@LBFHDDHDh@JE`KRCPEvGNCRKrWPCB@IIACBADAN@TBTADABANGHAHKNGdEPBTTPARFBFHJNBP@LAVHHJZHXANDTCrEDL@PBDH@N@BABEPCHA`FTAVGJCDE@KHETCpA\\GFQEGDCDAdBF@HCJ@\\DVEDBDBDBN^GbCRENCXCNBLDLHP@`CJAJGVXd@^KXUjKX@TFTHJCLBNH\\ZpRJD^CXBZET@\\EZA¨WhURK\\YĚÛÈGP@PE|BH@HCJ@FAdBf@`AxAVGNCZBhCTB^AJCH@XLP@JDT@JCRC\\BT@R|DĪYFfIpETEvEDnCXDR@`HTCVER@NBTFJDLJDB`BZFTFD@DCF@TB\\@HA\\DRBxHB¸U`I~SIdAvGzAPEhK¶CTCZEtC¬R¦Lô\\|R°fXtLhFNj@|KzGvECh@xLdBD@HGNAJCbCrQ`I[XK`OLAPEXEXMWZAPG^Cª[WQtE¾UNEDCpcnCh@TC@bCT@HBP@FBl@~FVFJANDHD¦O¶GL@NAUhMUIHARGNINC`KRC`UJEP@NEPALCP@PGNEROt[hUZI\\I¼IhAzF\\@PDHBbDL@FAJGNAPBHDLER@DDJ@BALAJCJ@DAJUJCR@HAV@XDT@XCJCTE\\IPAJBTEX@XETGHEFEJCXMLCRM¨{f]RITGdAZCX@PFZARJ\\BPDjEVï¹Ňɉ_ӟÛOƱ[åġƁuŷqŏµǯ¡ťĩũYMqcUScWYWu{qOGUIo]@MNu@GGOASDcBI@_DEFADEFO@OBCJCBECGLOBK@AOOKEACFQ@IRONGJ@XDHAFIHCFMDARKC@EC@CJMDOJIBCCEKFQCMISEAEG@AWFWBCQB]AEAEEK@KCMGC@IBMEMEKGIBOACACGICGGIMIIIBGDO@ECGEQFICGBGFE@EAEAUDEAMGGEGCOBYAE@OAGEGA[BOEOKIBK@E@QGSBGCEEcEECGKG@E@E@sSEIgGOE[EAAAGBOAGCAWCMCmESD[CKCaQMCKBWHUFMAMCUA[DU@[CWMAADC@ECAMDK@aAKDE@GCIMEAeMiCKAMESA]ISAOBYIkMEFE@IEWB]@cEWKaICEEKCAaBKGOCgWIKEACAOBI@SECACGM@EAEIIGQIKAM@QHC@IGiNO@QGAAEGEAG@GFICKGcOÁ]OMKEU@]DsEiCQCSIkCSAeFQAcKKAiCeOmCM]CqYKCCD@DJLADEBoEaGUBiGK@oTSBS@K@KDUHS@]IUAIE@ALM^[JKBECCYCIEUOMOEEAEDGHI@CCCI@[A]CMBKBC@GEYMEAQCAC@AHK@C@CEEMGY@QGICmF[AACAAEECGBCHG@ICE@EHGDICCOEKGQCIGIIAGEIEAGCi@OGMAY@[IKBWLWLK@UECBAHFDFBBDCBEBEKCKIUAmHaGUAIBUF{EU@G@MFC@_UCEGEAIB_@QAW@OBSFKVSFGTHGNESqSYIDIAGDGCAIBEPAFCGAUQLMú¿ÔGRÈVÖL²F]īHЉBCDCVDPGJFJ@RGbCFCDWHIBAPBTANGNCRDLBJ@NEDBNJLBBGHGDANBDAHIAI@CBAX@HGHAF@JEPADBF@LEPIVC@A@K@APKVFREL@HGVOFODAXBNIFQLKVGTBJGNADOBCNCLINIDGFE@EEEAEAAKECCBE@EIOCU@GDCF@^AdSHANBHGNQbKHGAKACEC@EBEDCP@RCHBNHJBHDN@JCPRHDNCLBRAhMVCJ@LEFCRGBE@EJEHKZSNUFIDOBOASBWDKHQJILGDEKODALELIBCGG@CHKCcDCNCJILANCFILIDECICAACDIFEVIDAN@DE@EEEAC@IBGCS@CDCBMDC@EGOBIJEDICCEECCBATCFC`CFKNIDKDCLC^ALCHCDKDCTADABGCIAKFEBE@CBEAMHSAKDG@MZYFEBKA_BKACOKGMAEDCFCNEHCFCDE@EFGBGEIECIAKBcAgBOBO@GEMAKBWAIBONYNKBGACEUC[GOKM@MEAACKA]AKACSKMCAaECACECaEICSCCQA{W]EKBWHu@KDSBgA[CK@WDYCQIWSsiKQMIOQEM@GAEUSCASCMMIEK@WFI@CC@IEK@UAAGCCEB[DW@CNG@GIMBEDEJEFQXGLU@EKEKCGGcCEIAKBQIIKAJQBEAEMS@CH@LDNBPKAMBKJS@MEIUC@AJ_RWJKXAXFLARINFJ@^CB@JFD@HGPCDA@COOAE@CFAPEDCD@LDZBH@NGJAHBFFH@PCJ@XFJCHEDGRELJD@fCQP@PCLCLK^AFCBAO_AKBGRO@EEIACFKJGBACASE@CFECOEaDGFCHCX@FADC@CAGACSUCGBIAAMMDILGDCEKCKIKEQAEDIDKHI@CKGGIAGDGVK^SEAAC@CFCLANDF@JCHK@GCGYQMMEIGSAUNSDAFBXGRIZGJEBABIGM@SEUBCNGDI@ASUACRCJE"]],"encodeOffsets":[[[87495,42945]],[[87852,42830]],[[93292,37025]]]},"properties":{"cp":[86.150969,41.768552],"name":"巴音郭楞蒙古自治州","childNum":3}},{"id":"652900","type":"Feature","geometry":{"type":"MultiPolygon","coordinates":[["@@NAHIXEHCJK`AHDTAX@NCNEZ[vaTGLOTOXKxUFEFEFOHIHClQ\\BRDXHVJRBFFD@DCtBH@DADAHSHEZAJA@EIKLGDENYBIEKJIJSpGH@LFXHDDBJCJ@PE^QJEDJRAREHE@ALZEL@DFF@DDFGFAFGB@HBBFADDBPDFCBDNDFFFBB@DEBDH@D@FDDFAF@BDAH@DCFALINDT@FBHFBHFDJ@HABAE@AAAM@C\\U@UDONOLIojUBAECBEDAAEGG@EAEBCCGOE@EDCJCDAFCH@HEDCD@DIAAFGPDJFFBH@HFPFBE@GLFL@BF@B@DFBJEHENMLGXEBABCU{BCBAhFL@dQNA^TFEDSFIHEDE@ICOKeEWHSFWReHMLOXYVQJGHApMHCHIHC\\GN@PCPIZIfKJAHDHAZKfM`EXEOĉ¡ӅEÙMqICQMCGU_qyҋЉəDԣAσBy@įAǝ@aBĳAƯB́AҹW˷OͯƄDRJ\\èH¬rÖRNHH@DC@OKEBCFAFHJ@DQBCDPBBDNHL@FABC@EBAFBFFFAJBFF@FKFCHBBDCD@@DCH@HDFD@FCHCFAFBHHBRADEEC@GFCH@DFFCB@DVN@BCDCHOLGLIBGHADBJ@H@VVPLBJFeĲMAABLFfLXLHh@D@FLpHnDNV®V®DVHXDHJH@DA^CNGNIHODIFWXKTMJQHONMVETENEDaHIHGLEVDRAPCRGbUVQb]HADCBARCREJ@VZ^lHPJHNJVJNB\\@HB@H@DDFJJBDAHP\\@DBRABEAABABDFOJ@DDBBJAHC@@FIFVJDD@FADI@EBCRHFHJADEBHDRbBD@JJLBLHBHCJ@DCFILAD@FX@NDR@NCJCHEDMJCD@DFFBBXCH@JDDFAFCHCFFL@HAdIRBXQPUF@FEJDD@BCDI@ABDH@FDF@FJHAFGFAFADAHFHLPGHMDCHBBbJHPAFCDD@ABD@@@CD@BBACFB@DGDAH@DB@@B@DB@DBA@B@B@@ADDEBBABB@CFFC@BABB@@B@@@BFD@BA@HB@DDB@B@ABBPHDFH@FDDDBFB@BADBBA@DbV~HP@^AdGTAFGLA@CEEHMEEJCBC@AECAEFEF@DAGE@CRODMLA@IJKCKBKEIGEECCI@GDGEKJCBCD@NHVRIL@BHHFBFLFTNBREPBBFAHBDRFNJLBTTHDFBLGDIFEfEFKROTE^@HA@CVMPYFMFCzWHCHGLUNEJGLOFOPOFMbaD@FGZEPGHAFAHGFMBMACCAEECK@EFCFGJANBHD@DLJD@FFJ@LGDCAIDE@GQK@GJI@E@GLE@AEE@CEGBCFIAKFEAA@AJG@EJGDIJ@LIDEF@@ABCAKEGBEFATFJBHDBHDB`BHDNCFEDGJAAEDCLCH@FBFCLM@EGGCMBEFCCE@CCE@ARANDDBHJ@HFHTDLAJC@UAGDCJANAPILBDAVGHEBEEUBGLILETAXALDJAWaB@ACIEIFCFAHCBAABI@EGGG@AAEGE@ALIHCABECCGCC@ADC@CAECC@A@AHA@GGMCADCHCD]C@RKxc\\MHACG@CDCDM@EAADEBCDBGACA@EFEBBC@ACAJCMDCCAACAFCACDA@CE@@ADCDBBACIGEB@DADBPATBP@LCBCCCG@CCK@@CB@BCFCDCGCDCC@ACCBMBABCAE@CBAAEDGEAEAHE@EIB@@CACC@BHMBEDIAADEBIKDAHBAKBEGCISKC@AFAAEGCGGMCAADIFAPDJOJ@BGFEGDAAADCA@CDABBDGE@MHIBE@LAVIFBCB@FDCHBABDDJ@CBKDBBJB@ADAL@HCJBLCJ@AAG@QDMEABBBECECBAFAFBFAJDHADCF@BCACFCIA@AHCJBACFADADGJEDB@ADBH@@AH@@AAAB@DDDAFHEA@CC@EDAAABBFA@PFRBECG@AGFBJFBA@AMEAC@EA@CBCACCBGDBBFF@ADB@LEDBHFBAFBCEA@EAB@ACBARJJBAAE@@CDBFA@DF@FADEJ@DA@CKAEDAFEBBGBBAFDCDIFAD@@DDAFBRABDKFjJĄx\\PBCB@PFBBDAB@HDDF@NFFFBBADMHAFBLLHDVHLCR@PCxKBC@CTKFGRYǨ@°`LĆF͐AĶ|ĊBmb[XĝƚGTOTQJSAARGNWLIFKL]FUHIHEF@HDHPRj\\VRrZP`J\\RhR^ADFFNP@Ddf^fLLNLf\\`\\r~NZVVVZJRDTjh^TvjbLdH|P¶nNN^PnXphTTNJDRzRL@PBBTANCJ@XHTBLHFFJJFNHNDJDFj\\HHHRNNJBfAVBfTVRFPAHFNBT@VAHAHPlPHHHBJAbJdJFh@HBFJ@TCLEHBdFDV@JCuPE^ELGZEbAZBL@PEfCHFLB\\CFB@NCJDBDBjBTDHAbSLCFCHM^QRGTIlOhW`GHCPKLQDCFEJMJAHEDEJGBQDKDa@MBGPSBI@MBKAG@SBIZWJODGBELEHGFMJKJE"],["@@DABCFADCXARGNAFDFJ@DFBH@VAXBPALBFNDBLCHBHJ@PLHDFFDN@VGT@FDBDBFTTNPHBDBVCLBHADCJ[DCBGDEFCBIGECIBEECGEIMOMCKbANF@DFABCCWNBPAN@JFLBLDFF@JLHL@THjHPHDHCL@TTNRHPFXAVCXMNMJKHKHOJMPCVIROZKFEH@^UNC\\FRHbJXDnDTFVNdNl@T@TC\\QhMRMNGP@JJZLRFTEPIJKBGLIHMAUCU@STKJClEZKVA`BTAv_XE\\CTBRF`RZLVFt@PD`PZFZAVD^TPDJAdMX@LJ@PEPJNhHjEZA\\C\\ATFLBLGTGT@^JP@OVAZBREN@xRFBFCUOBSIY@ATYFKAIMOEMBQBECIJOBG@MEKBKOQAA@KDSBSBCAIBAB@N@DCDGTERM@CCGCO@AJOBGACDIRS@CEIFABGCO[UCGUUAAQ@_B]@yO@CBCLM@SCOHIDM@MAGQ[@AFEEI@CFCZQ`WBCEIJGNEFGPiNAcVoPuN]DENKFEHUDW@UDE@EJKBOAYE[OgOaCQBKFMFSBKAMGSKiCEGIUQOISYY{ImAoI[AO@KDI@GIg@kC_@QReJMHGNEnGJC@GG[AS@IBILMTKXGHGFKPgJQLO\\]BMA_BOLJaDMDcCYCkEAaBaFsFWJWJOXcPMbSPCHG@CAEGIKQ][EIH_BS@OCGBCAAEKECBEPUAU@SJ_H½@×IÕWF_FeNYLGBGCIBeLYJOJODM@[HGDGJGDoNGBIHURWZKPGNQfEXGTFXLfDP@JCFGFEJCTEF]SMBcRK@gEABADV|ADABWFKHMNGFIFEA@C@AAEK@KE@HAFOEGEG@EAIEOCEHBBCJC@CDGFG@EDCBIDCD@FPFDHADBF@FHHBFCBAFFDABiVpKJMPCP@V[V@DBNBBF@ABGBI@ECAGGEEAS@MCKJEBCDG@CB@ABECEECC@G@ACCFA@EAEEMCACEDOCCABCAEGAA@EHEBEHCCE@CEK@YFBKF@FGBQIQFCRIF]@ODIAICCWGKEG@oHITIJFLAJMZCFKHJL@FIBYBGFGTCBCBG@sACDC@EEQAUIWGQC[AkRGDGJEPEFEFwVWLSPKPSHubY\\MFMDW@SBGC_BILGDWFGJMBIFILENGHKFAFCHIPYXAJ@TBHAL@NAJOTAH@NCbCLARIHCFGFIBINEFCDKROLGD_HgXkPSJQH]RGNEDKDaTGBSCiACACADI@MEA[DKAGEeDOFK@YAaBYFKH]FOFvIDU@ECAcFGDK@SEIGAg@IEIcBaAIGGOGOkBGBG@UASEMBGEOUQeSUAeBIAMMGQGGi[CECIGMEMIIEEKGSAWGI@MDSBAOAK@yQQICSMgSomW]OMMµm{OcGaKui]SigCSIQUYUUMYq}_[e[MK]cYBOD˭ħÑsÑh»gHǁÃųHĻkP[HaAUEoAK@QFugEMC@WQ[AIEEIOAKB@Q}]ACGEACCCKEWEFJKF@H@FIJ@HRL@HCFBJCDKHI@EEC@KI@CGCMAIBEHED@FDLFFDBBDANENGHEBGBOHYFEHC@abENOPEPKPIHMFKVGHGDyXEDENOZUN@DGB]@SFQPELeFEFCJKHEAGCSSKAMIQEACBGAEOAQFMAESEKEAGG@AJKUQMGC@ADIDFLCH@HDJFDHFFJALDLIL@JKBCNQP@DHFCBE@EFBFFD@BADIDFFGNFF@DKBEHSBcH]BO@}GaU@CABCAABA@AECCECG@CEOGAA@B@ACA@CGAB@@AEC@A@@@AA@BA@AEDDEA@BAAACFBC@@@A@AAB@CCAA@@@CAG@CBCHA@DEAB@ADC@@C@BAC@DCBEGOaIAADGNCHGKOEGBGBCBEHEBEIG@ECE@ECGBAJ@DC@ACCFI@EVEROAWJQBc@GEKDEDGBECEICG@WDAAEE@CDCNIFCDGDI@MCQ@MEWC@KBEJCDI@GDGAAKIK@IACQaGCFABCGIGEDQFAJ@BC@ECCUIJE@ED@BGAICA@CPICEBABAFBBAAQ@CO[BGACIICE@C@GGA[@MAUIMIIGGO]kUYI@QFQDABCDGBa^URaVQHODQBCFUHKJGbGFCFMFSNUPMRGNILSXWJEPCJGHMF[@SIGCGGWCUU­U­CMGmKo@E@CGgWKeKKEABSHGBICM@mJGBWCmFGA@CA@GPM@ťz÷ơHF[DyBcCY@Q@kJIAē{MU@qR[Jq\\[HYLK@QAMEIGoS[EEIE[IWMKOCKKOgKcSWIUGYEUIGMICUBMAUKGI@IKEKCEDQCAIAWK_IMKMAACA[ESQIOGkMM@IACBOFMDCCJOCCKFCCACkMKEAGC@G@EBOC_MSCYAUMCAMFGAAB@HABcNUNGJALRJHFCD[PGHSJsDWDK@KAaOK@ODIHM@wAeFKDQB[IiCSBSDG@KEEGE@SL@HAHOJGBMRKBWEKBOLEJALD\\\\VHDPTDVHLAHWTADBJNVB\\HPHLVPPPFT@RFNAT@JDDDB\\@RFJFLNH^LZPN\\THRFhCRCF@`FHLHRJTNNLZPT¢jfJRHbVv\\fV\\ZJZPNPHRF~`PNJdHJ`XNP^rJTCV@HFZXhLPBD@DCBK@MAUBGBCDAbE^CJOHBHJNBJKN@DTBLFJHJPFBVANDHFRCPB|bVFVAND`X\\HVDP@PAJCFALFJNFNXJPHJJHLNLJDn^JDTDVHXNDFCPORKHBDJFBDDT@HBFNJHNFdDPDH@JCHCHIHGDS@OGOAMAGDIHKPOLKNITIN@BFD@HER@HEJCBGL[\\OLCRKVKLCTGNATEHI\\@LEH[XEFELCDYRcPGDGLe^OHKBURKHCHGFOJONUPKJEBG@OPGHMD[HOHIHEFOBWF[REHQNEHKJEL]LUXGL@DEF@D_XGD_FCHBFEHSPpDLDX@`ALBXJLJJ@\\H^PJJNDJPTNHFHTHNDJBHAVONEJ@`JRBJA^OLVDLLNPNFJbV\\LBFSZ@NFFNHRFpHJRAJDLPPGPINALBRVJFPDHFHLPPJD^ATJVPVNLLZP@LBFLBLFRRNJRBLBZLHFHBLAlKH@NNDVFFLFxLtLfNLJHLDLJHNFD~EZHvJJBF\\NFLALFDhTRHBTMVINEJBDHJHLHtjNJZJhHZFJFV@TAPGFA\\MPAdCrBRF`FhN`LLJR\\VVJH FRFVBdJpBXAVKLBFLLNLJJP^zBPVT`RNFLJFH@LEP@XDLtV^PZFRHRDz@nChF^A\\DND|DA\\MvIZAjHITDJRPh`LJORYDIJYrMXKPGTJBhBBBVFHjJRALnVLFXD\\NDLBTFVEN[XGHCLDXRZFRRG\\BNEPAHBTPF@jIDBNLLDREHCTEBEDELED@RID@HDXCJF@PADBBDB^@PDRAPTFJFHHFLBFAH@JJVCHJHPFDJBdBNDP@RFF@FCJBR@VCJEN@JCTKLFFHRJPAFDTEZIJDJ@HFD@RAFDD@\\GHC\\AFDFHNCPBBGPKFGLCDCXGXAhNVRFCFEVPBDADB@JBLAHDZCVHDDFD^ERED@BEHGLJT@FANAZDHXRNR@LALIIKDADEBGFBFAFG@CNIZMDSACLEDMHCHGBEDCBE@COKDCFMJKFAFDjDJBNFBAJBNAZI\\S\\aHARDLCHBAFDRJJDLADEFMBEDBJGpBJPBN@JBRAFHBNFDDFNHLGXB`AHBD@DCNHT@HAJDPADADENCFABGHFLHDDP@LLBLHHFBLCDE\\QHILIFCHATBLD\\hH@JARBPFREDPNABEHAB@HHFATBHAHBFB@NFHJCRSFAF@TGVCHCVLD@HFN@NAD@FDX@FHHDJBJEDBPPHBNALENAtFHPNJF@XLJ@RODGBGCEBGFCD@TDFAFFBDJCbCRGFGLGJBDFPFHBFHJHFBJJjlLHPDHAPOFAHIAKDEHCPCBAR@@BNCBAL@JDJL@DEFAFPH@DIH@LFFXER@DArCTBhKN@RDTNVV@FBDHD@VArKH@RBHDDFDPJLJDL@VAFANERALBHFLDHP@HELH`CVBHDBH@NEBEDCTEhUNARPHLfTTHRBVETG`B\\GNEJ@bN^DP@DPDHLFL@XCFFBDEHANFHFN@DQLBHJD\\@RLXDFA\\Y\\IZJFP\\BdEfF\\AXATEPAjPR@\\KL@RHDHJFN@LFBBBNADBFPNBHDDBFKPHFND"]],"encodeOffsets":[[[85068,42231]],[[84622,43621]]]},"properties":{"cp":[80.265068,41.170712],"name":"阿克苏地区","childNum":2}},{"id":"653000","type":"Feature","geometry":{"type":"Polygon","coordinates":["@@TRVRLHVBPH\\HRFVXPJF@VIJ@NANDTE^DDAHMRBHFJ@RLN@HARPbFNPXDHDPF@BAHDBV@XJXFDHFBJ@PENHP@JDDJHNDN@dBPAPLNBFB^CHIH@DDD\\JDPPVDFAFWbELBBPDDBANHJVDxNbFlJFANIHEVDbIVHVGRFLGDEJ@JHRRHBTGHARDPAX@HDJH@RTOFGAEDG`EHC`W@CFE@CHKVW^KFKLIFGRMFG\\QXEPAFEJGPG\\GNCHGLMDAH@FALIVOPMPIHEDGLGVQLAPGf]HKHCdOZQDCFKFENKRQBMJ[FGBSHMDSLKLUDQPK\\[HKDAFI@GFQ@GEC@AJMJSLMPKLOJGHC^DPHJ@J@HCJGDGDG@ICGCOEcGMMIAE@GCSACIEACLGPQDOCEWMUGSCICm]ICMKGKIIOGWIEMIMKEEBIDOBO@UC[G_WMCUBUE{aOAQDGEMCUBEAIOIGKESA@CLMAIIMAGPGDIF]BaDCHAVANBL@DA@CACKOWgEY@GDUIS]qMO_WGIIcOM}_QEOGOMYYI[eUu[aUQGeI¡iSOIWQSMQIKGEG@_DEDQEgGQ[SOMKYG]KMIEQE[@CACC@IBSEM@QESOOUOGKGOA[MUAIBCXSBGGKCUOSGC[UC[BKFIPKLAXFLANQHAPIBG@GTKF@FHLFH@TCTAjD\\JRALCfExBN@JGPCL@bPLBL@XCtCTIHG\\ODCGEQIBKHIVMfO@GBAECM@aCMDMAEBK@MHMBEAIGMCCCCBCCCBAAIBAACBGCCDSBCFCAAEEBCCGDI@@BSFKEG@ACICC@@CA@@AMBGCUCKCCBEAABA@AAC@IGGDA@ABA@GA@AEACAE@ACGBCAG@CCGBIEAAM@ECI@ECEBWCOIIAM@aR]HcBM@OGAACBGEE@gBWIKBYDSEMHYDkAuLI@]ES@Q@ODWFc@IAEIEASCCGGCMCU@OCM@UEOKWGeGiE¯CAAKOICGKQUAEOGCCAKDED[@GACUEMABK@UGaA©AOAAADG@CC@IB[@OD{@sMQAsI[@eE{DuH©DKAUFHKA][WGŹYqAKCACQIOIIg]EGUS_MC@AAqWkCEokOGkU@AEGMCA@@BC@@EBE@IDEC@@ADC@AKOC@CCEDGAMOUIOAEAGDCAO@_BCAAAE@@AA@UHCCO@E@CAE@GAE@GII@MIG@EBECE@CCG@ADEBCCCDEAEDGAIBKJEJC@GACBACIAE@ECCBIAADEDKEE@EDC@CBE@AB[AGBI@ECEAIDE@KF_AABGBOAMJKLo\\GBcJIAGDG@GDEBE@GCKASBGEQAE@ABE@wOIBOPQ@CF]CK@EFSEWBEEGCKAýKAA@CJWHOBAIASLI@GDOCG@GBEAMFKHKCE@ECKBEBGAGEG@AAaIsE{FOFQEM@SAUBcHIAQ@iHG@OCM@UDFdCFCDcVk`[TIBGAKJWBQFmHO@CCAIACCMC@IDABCTCBI@ICAJCBII@CCAKAIE@CHK@ACAKFIBCBGL@FBHC@WCoBKPECCBCJGHEBKA@GA@MBEGIBC@AYCKEC]BICIAI@OHE@YAcBEAAAAG@KAGGI_C@CFMTUFI@CFUPEBA@CY]BOBGFKXi\\gLU@KIEQIIGCGMKGG@CAEAAU@KEMMUDIAEIEUGI@ICEGeAK@KJÉ\\ÉNirđJDh@fFL@hJXJL@hJbNPNFHJNDJPNNTPJAPBJ^RhRNBFIBCZFF@BA@CGGAKBCDAR[DEB@FBX\\Nb@TNDDFBADGD@BBBHFDHBJA@B@FLA@BAB@DJDH@PHFCB@BDLDNABIBAD@DFFADFHAHFBA@EL@DGFBDFPBFALE@AaCI@QGKBCGKGQESKMEGCKoCUIaSQU[aouISS_@GKYEWDESEQOaAE@GAAGGEOEEMEACACHMJKFAzAHBD@`IDCDCPKF@F@RPRBPCFIFGD@PJFDNFFDJ@CJBBH@FFDADCJAFGLBBD@DCH@@BDD@BDF@JHNDDDVBDHPBDBDD@JAF@@RPANAFAHBDHH@HELAPDNBPFPCFULEHADDDLFXH@DGFIFIBmBODWZGFID@DJD\\J\\RNPpNBVGH@RBH@VEdBJBDDHJPFDF@HCJEHKHMBJL\\VAFELBBXTb^FBedAFdFP@TQ@AEEB@VSLAT@^HNBR@JENAHEL@VKLBHCNHJA^[NEH@PETGRALFDEDAbBhOVAPBHAR@PFJ@LAHE@CACFMEKUS©[CKOEACAKC@EA]B@BXH@FsBCAACCKGA@ABCXAEIBMX[PKbcCS@IBGFGHGFIBM_EAACEKCEE{_MC[CAMBMDW@WGQAaBKDMAc@ILERAZAHCBQCEEOMMCUGKM]OEGKKSE[CQEKGGAUQKAIGOCIIIGSGKGKEAADC[~YâXUR]HUBWBBDCBAEGN@BAEEAIBIAEPAHCBEBIFEJCLDDFHFBDD@BAJ]DK@GCOIG@EB@lJTBN@BAIEEEDENARBJADABEEICI@EDEJID@^JDCACEG@CHIZODKBE^OFGTGJAHC^[HIJQFAhCRKDCACEGI[EGAEAQBEBCFAL@hN^C\\BvBJAHBJFDFXJrLF@LGJC\\@RBL@HEP_FARE\\AtFTDP@FEEMYDQ@ESOOGYGYGMECCMaBELEXIjIJ@F@RFdPDJA~WDAFIfIat_tcJKDGBKEQCo@gEËDÍCOOSsciOYMmNB]CCICGIGOAKFK@ECE[UACC[ACDIEUBGDGCEI@EECIDKAGMEGQKEUQEE@CBEBCFCBEMI@ABEPSJQ@CECCM@CFGPEJGBI@GEEQGMA]AQD_LQLMHABGPEDC@MIWCMAAAHOBOAIEQEWSIgEMCeAIKIEACAMBGDEAIGIQgGOQi_@IAEEGBAB@RQPMHEFGN@HIHKVIBMHADJJBNCFMDCD@LCBE@YEECKWECQIYQIEI@QDK@MEMMWAYBGCIMEAMCSOeOYGUMI@I@YLE@aQI@GDGDSEMAcHWMEEGSEEIEIAoaQIEEKOE@QBI@EBQA]KgcIACD@PHPCX@RETCVAbAHAJBFFFFNRNA^JLRH`xJFPPNRDHAFEJUV@BDHJNJFPDTNZJFDFHDXELCDUNCJBFDHBHAHCDcHEEECUBEGA@I@OBVSDEACCAIGCACFaDCH@BCEEMMiGAA@GAAC@]TEFCDC@KESGU@CCQIE@IFE@CGSYE@GFeFGBCDALOFUBIBOPQDYHkVIDG@UCGBGDEFIDK@MGMCK@CB@LABgJU@KFKCQIOAQGODE@GAGGA@NjANCHHTAB@FHRCNIL@NCFBDQREPITAFKLCHAN@HFJEH@VAFDLABAR@DHLRR@F@FMJEEC@@BKPYFGDGJuptqpOHQFWGIYEO@WHWLMJQRWTIFMTIRMNCL@LCHO@±OOCWOMKECiCGCIEIAKBEDAFCDUFYPIRAHGBOAGBGBUAUGQGWFOHaF]EIB{PGFWxGLCLBPPTb^RNTEDLZVLPJPTVHXGhGR@rC`KNUFOEa@MZAPKRINMJGHOFQCc@[EOBMDYLzz[FOEIKI@WLaJHmlUNOBoEgCOBgT]JsFeHoBGeFmDA}LkLWDOJUFIEIG[kEqESKEqAQYUYPcJOJYHIS@AUEW[WAWNSDuBuDQFIJGTG^KVIDYE{NSHKFYJSN]PCFDNPLDPSlEFEJWPGNEXCXETYP@dBHDbRRDJCJMPMTOdOPIFEJEVIHUH[ZBTRtPPHBJ@HFANPXLVFBX@HBLJP@FEdMZDJCLYPC^hFVD`@TEZAbCNWVQnGDoAGCEUIEYA[BWFEfS`SPCRDxMREZEFQBEFE`GFaESJIT@fYPKxa^YH[C_BKHE`GJEHmHEDDJV\\FLENINALH\\JVBLCHcXlBFzFlJbNnXJPFTHpNZZHXFXB\\CXG¢EtEL~BFDZBPDRJ^HJRF\\JT\\ZCJOPBPLL`JPJJNCLATNHPBLAXDJPC`K\\MtIfKRBXATQXLD@DAFGDGDCPGJIFQDS@MDSRIBQ@EBSACBGp@jD\\JdNThbhRRFNHLNFNDbENMZ@HFPPNxxBH[J_HMF@DFJNJXBTHTBfXJLDVDLJTNPNHRFNB^IXMHAZARDNBRHBJFLRPHRXHTBPCN@dHTBVKNkJCNDRNTFLAVObQZALHRJzh`PdLTLRRPXddRNl`RHfNHDRRT^Z^PXRRVLRFZDXANCZKNANBTPXZNXLNFNDVENCTFDd@pD~BCZErY\\IfBZRN@PFFLELGF[JKHUTej]\\CJDJXDPNJxC\\BFd`P@vMlMbMTKVQHIdKZUnOTCRFNLVH|cªSL@HHDHj`MrKVE^@lBVfTHHLDNDBTAX@TNTbPLLHRPjZzX¤\\fnNAVN@Rz\\f\\lfP`D^BLI@KPCNSLKXMSgH@S\\aB_RQNIPGTC\\AfW\\IPKDMQMKMESOKogQe@eMcFU^QJUNYJYGUEQFKRCfNHJPNLEHBPFRJVKRDTJTHRLVTLDT_dARBpEVENGNQNCLHHLDRId@PHHRDNLJLHDXhLJZFPENODI\\CRSN@`DBHE^@NFNRFZFVBZCLE^J\\@`ETEVGRGFAhLdPVN\\\\\\JRHLHRTJBNMBIIWFKNEhALEJOJGBOAGEIAOJUJYL@HCFRDRLJLNLTbVHCHWL@RFHHNF\\APDJFNXXNJJJPVJp@JDDRBLHLJHLDJBHFHJFVDV@VENDVRdJVRZZXNJ`NHNLbPNNFbDFHHBRDDD@JIb@RPVBH@bZV@BGLCNIFGBGPGJMXEZFV^T\\ZTAPCJHPR\\dFLTF@NANOJBNTFBHEJBLFXBP@\\DPFTTbLPJb\\NTBZADLPLTFTDT@PAR@@NJhT^RPPFVEXIP@tRVP`dFDHHTN\\LJBRKHGPIpBdFZ@^@NCTKJE@GISFE\\EVAPOZERKJKhHHLHFP@P@rL^EDA@IDAVARWl@RDTJ`XvPLRL@`ENOTFLJRBTQREHEPEzDJIEenE|PZDLIFARDR@TKPENAHXDBZ@LH`@JDJ@\\JD@PGjITDhLbLJHDPnUVCTFJTBRHLJDR@NCT@NLDF@F[bIXGJANCDFHEF@HBDFTHPHH"],"encodeOffsets":[[79684,42123]]},"properties":{"cp":[76.172825,39.713431],"name":"克孜勒苏柯尔克孜自治州","childNum":1}},{"id":"653100","type":"Feature","geometry":{"type":"MultiPolygon","coordinates":[["@@pKVGPAP@LFJJ@FANKl_¬Urgh]\\ij[X[^KJE@IñUyI½O¹QÍǒJBlIR@Z@dDzA\\CE®Oż{øŦyN@HOB@@DHBnEXDHAnIN@JDHATGDCL@BBfıIEKAUO@U@GAIBCHGJAHKPKDGDC@AUM@CDAEE@CDGHED@DFDA@AAMCGECMBGBADECAA@GDG@CC@CDAADGLE@EEEIAEBEEEAAB@FADEBK@MGACOADCRA@CGIBEDEFAPLD@@CGGQMqÕG«[çIa×_ãҗȲnLxNJTBDDJBB@ADB@DCDA@AB@FFD@BDDBN@D@HHLDBDL@FBHA@BRAHDDDLBLABZCBIBG@KHCMWCOBGJAFBHFFNFHJDFAJ{|@FBBP@ÂNÄPd@bG´_H@"],["@@_EiC]EÁMsKW@cE]E[ICCAABGFKPQDMNQJUAAICgCWEACO@E@GAC_M]MYIMINUD@HBF@PCXKBCAAEA@CDERKHSC@IFGBM@{SU@CAEGASQMQG@CCAFKPENIXGNGVCHAL@TCT@PFRCFCBCBCECACBGIEDEECAEA@÷@Eg}@BGBSJiJOFSAKECGBMJKMEACB@DHFMTWEICMSG[A_AGACCCQCGKEAEDMPERQVIHCLBBBDTFHHFLGNILABJDJ@JDHNDN@FMJILGHODSEEFBLDBJFDHDN@LILOJ@BFD@BEF@VFJDHADGDG@OKG@A@@CECBCFB@ACE@CLK@EGMoOKCWYMGAC@ECCu]gOEC@CDSFOJGLIBCEG@CVIDBJAHKZCBEFC@CCCJYBCCCKCCCAC@EDEHCNCV@hB~NbLDCFGAES_KKZIF@\\LLDFCFI`[FCBfGdBPJRD@F@TBfDF¤VhJV@TLNN@JFHTZLL\\BhCf@lLҘȱeéÛ̳iùCQAKDM@CGIIGNUCIBaMWKKASC]EEOIKQGSKMACCMCAQBODOHYPOH[B[DaAaJQJK@_F]PWB_HEAECCIGK¡_G@KFIB}DeCWEaOƭă³ȃĝɳŗ_YĽĥĹğǩǉWWgi§ƃƻ­¡UWMYBILY@EGGQMSYMKAEW[ICIAI@WFEAMKAIBIAMKC@GDKFILM@EEGEWFWFM@EEECGNmAQCK@GDIAIUoE]UeAMCGBIJEAAKCEGLM@IKKQIUICGBQAGCGSQEG@C@CFCPWNGRERIPKDGBECM@[BGFGLEDC@EEMDIDCFGDO@IACQIGGDCJEJKJIAaDI`aAaGMQaDQ@ECEOEGEIWAMBI@ONWFQMICEC]COKSUOKEIICG@GUc@MCMEMAG@[LMBGCKG@UH_@I@EGK@OHQLG@IKUKKWIMiCEAKEICGDWFILGHAXULSJGPIHKFCTAh]`OPQDAPBDCTYJCTAHCPSJSBI@AWCECAYCGIGEC[@MAQCcMAA@EAMFANBDAGUGAYAI@OFM@WAIMOQKCCECWGIBGIKAEICOKKBODIBMCUOEAQAQFKAKCQFKE@EDQAEGIAY@EFIf[RARBVCL@\\FX@JSDCdIHBLBPQTELEJANHJ@RQPILMBG@GF[bQLOLKDGRU@ICGY]@G`WBEHCR@TMDOBCFCPBJERCPUTOXIHCJQFCHCR@PHDAJCJAFBNPLJFBrDJCLEP@XOHKLEFGHOjgHCDG@Kd]HGBGBALIZKDCBI@CGCQAKCI@KEMOK@KBOJMAMKMSMEGAGCGGIGK[IAIAGEACBgAASBQEI@cHMCEACEAEIGFKCUBOAI@KNUBSDIHEZGPAJBHALET@RAbQxWJIDE@CLCXBFADA@EFKBCFEBOFGFADEFADGFAH@LJHBHGAGFGJCBC@AKEAOHIHA@AGEKKAIICGCKAECMC@IGEG@AHCBOFCD[BEAGDC@@OHGDCLGHIHIDI@C@CBGEE@CDSBINELaAKA_ACQDUACEGKCAE@MJC@EAGK@MJCTUES@EHKPG@MCCEAQD]AGCCCEYFMEKDCFER@PKDGLG@MJKEISSGCM@EC@GHGHERE@QDMDQAKEMDKO@GAYMKC@IFKWIMIE@BM@EACEE@GCEICAEECLGHMHODEF@LHHBN@FCDUEACAAABEQKEME[IAiDWFOBGI[QIOCMFOECICc@OAIEEIG@MPa^SLQBMGBaGEUJWFYDQAIEC@CFALEHGFLQKWLaCsMcOOIUBiPoAQFOLERBNEDEBcAOLQpMNoTKiMQa@SHQNqTk`qP[N[XMTOJ_FgBUJSLU@KIEKUIYGOBaR_HQHULWXrQZKJGCQIkAoImCODSrMPWTMRONgRAdIPQFQAiNILIFG@WAOEaLWJIVO\\KJEJKZNPXTFHARMdDNRVNXIVINWNcFQGGaKMq]oPS@SEOIikWOSCgDeJ]NSKCQRkAEJmPSHW@QCYEmD[AEWICc@CWF[R@NFPJJJVE\\@TJRDNBLCPSfIJKTKLILQNKNQ\\CLEJD\\ALMHeDDGCYOGASDkPSL]VMRGN@TODPRORGLCVHPBJKJQJDPNHjDXPMVRFf@jH@pGxAZTLvMREJ@HJEZMTUN[VCbKNMPKDWRMhCRBXjJHXFHPFVKjGPOTDDBDALEFAJEFAHKFI\\OFCDALDH@JGDKAK@KHIJAH@LDF@DUJEDGJIRKNOBEDEHBHJPHFLFNLBHANBDC@ECIBQXSPMRIHI@WJILAFIFAFGHGTSJGDI@IBCFULCFAFEFIDGFQBITCDEDKBED_POBGDEBUVOJiRWGOAOPOFMLR[BQ_NoBWDAQEUFoIEMAUHS\\[IOMSUOAMBINGPGJMh[fCN@XPxHRExCZKTUVWLKHALATDLHNPBLDHHAVEJSFICOAYBYJ[BK@yR[F_BeEKGMCYCQDQLMFSBkN[LMHHnqXYEEUAAkA]BiKWBiTSBOKYWMIYASDMAKGmGYGOIBMJYLOBIAE_DEQOEUBMHADaCPKVQVULKLCNHVDZA\\SC}AWS@[EEQ@aCU@cDSRQZFVCJKHGNCRMJSAeUuM_GGGCQSU]IqISACNKTOL_lMLOEUKCGEAGACDAFAPATAtaRUFKLD\\LLbRHNE\\UTAPNNXLJPJZLNlPZDPGPCdYRBNHD\\FRTBTKRTNDPGNSHQLINCLHRVLRXP|`XFPANGfaJCZQNAHIH[JONSP@^BRDhDXFXTREXFJJHNJvFLJFVJ^DdC`BbJVD|VdN\\N`AXCZDNJFtXPAZSLKPFNLJHHTLLDBJ@HKZO^CLOZYNsjOZEPCHSDEAeQOEG@QPIAYBMFAPJNKJiRUHYL_TSZEdKfMbGRapCHAPLJnXFPA^BTZ@ZP`^RXPNtZDJCPGHYV{`[L]RSPIRLV\\j@PKTMLIP@|MXCTBRBJHNDPJLDXBZGRUJSEPIJSjOTilWdEjSpERCXX~Bd[pCZOhPPLNHE|OJA^FbEPGXERHVHVBHAHAPBHABGJQZOVEDCBEFCLAJBJFHDjDFDNLXPPD²PP@DG@KDKNMJQNSJEXSRQNIXKXGP@ZFJXHREPGrosvoHIHCZELO@AD@FFNI@E@EQQGK@CBQBACKBE@UFGEI@GBMDGLKBEJSFORQACDE@MJKDMGQ@EBAGSDGBMMiB@HHHBF@PCRHPBRJLDLEV@hIBA@KDAL@NDNHL@JCFEHCHAVDH@JClUZGRCPOJAVAPEBKDCHAfEHEF@TZDHF@JEF@RJDDV@THLFD@DCFE^SD@BB@HBBjHNNFFADG@CDEbBDHDBJDDFBTCUPAJ@B@FHVAFDFFdGDCBGAGCGAEDIVMDCFKCWEGECYISMOCIEIMCG@AVUFIBECGMQOOIE_wQGIKB]QMEMEEAEBIBGBaDUFS@QDWGO@ODCJBhd^LRBFAJ@RAF@LPFFRJpbJBJFFFHTFFXNdGNBTFHCHCJ@bRF@ZKJ@J@VNZHfPTPNDFBJNHDZAXBNNNFL@RCJ@JFZRRJFDLXFDZFF@DA@KDCNCDEAMIIBCNGJALUJG@GHMFENGRO@QBAHAFFJB`@RjHPRhHJBJCFAHBNBDJFJLfBNDhFTJFXFRBJAPGPBBNBXDNJD@FCHOBANGRK`KRC^BNBRHFF@HAJCDEDOFEH@DDNFD@DIROTAF@BNJAFEDADAF@DFFVRLFHRNFBHCLDJFFJ@DFCHAHFVCJBDD\\BD\\VDF@FELBLHPHJJDDDA^MNnPZdjtPTDPCÎFÌ@hDpFRALCHILsds`beJEJCB}XIBCcOQEE@I@iJWJKFAFNbDDNFZHZHPHTP@FCRNZFEFO@SCsE[BQFEBO`GFK@QA[@IDKHE@qKWICEIEGAIBuA[A]DgMK@EBADAFBRBFFHJ\\FHBDCDQLgDEBIRGJ]\\GDIBSHEH]PAFCLYPGJ@DFHBDCD]IC@IJCF@FDJFJAFCBIBQAMBCFFFJFABM@SAkIA@@FJHDP@HCLI^ABC@ACGECEKCIDEFAJAFGDOBBFAJBJFFABM@FHABCDAAAXGVQ^WVá}Z\\CDBBLFLHTHJHJJPDJHLBVRHBLHRF\\DTFLLFH^PLNVHNDPNFFRDDABGBYFQJKd@NBLCbARBXHX@NCNAB\\DND|`FFLDDFBB`FANEJGHEHAH@JDTadOLW\\ANFJWBAD@BHBDLBDDBtA@EWG@A^AFBD@BLBDPFDLª\\VTFLENBD@DGFKBI@OEQ@GBOAUBgPaACBCFKEQBSHOFG@MF]\\IBMGGDKAULK@GFMBIFQ@MA]GS@KBUTA@FF@BSRO@cEBEfcEAa]WSAAFKBE[UIKNALGFGDI@GCEOEGICCIAcAUFG@QAG@UHMAoMO[Q[IIC@CJCHEXYPCnAJAJEHE@CWGKECCBCFGVKDEEOAOCMBOFK@GGGACBGBEBMQO@@BE@ICCCAOACGUACCMCIGE@ACC@AC@@DG@CACKAEHIBCDCBEEG@AADII@ECMEECOIC@EHEJGBWBAAQOE@E@OLCDCD_JC@GAu@IDILGNDHNFFFFPHHBB@HBFPbFRFTCFXLZ@HT`JTvbpV\\TRJbBPLhBLHFNFTLRFLHDHLARHJ@bD@BKFEBOACEEACHK@@FABGEGBCEEBCEC@ABAJMBKCACA@EDOGG@IC@CBA@AKB@E@AIBGAECAGAAC@CHABCEMC@SMaW[EAA@CFQ\\CBADBLHH@DABE@YEADEJMAgQ]QAIBOOIMSOMCIIMEGOMaMgIK@WIgIK@eEg@ICqĒMj[ÊIÊ@LBLHfDF@JHJFVFJJBVCNNLFV@BBBF@DHHNLDHJHRJJF@D@HKV[hWjGTAPZ^ADOHEV@DEJSVEN@DB@^DHJBH@LDJFBdAZBF@PGJ@JBJD^AFDDLBZD@JAFHNAB@@HDBNAJKBEDAFDLOpAXDD@AG@EHKDAJALEDB@BGL@DJFLBDB@DJJDABIJDJ@DADSBAJCD@DNBDDLFBXAbEREXALIHBJA\\Sl_hYDEE_BCbCPDrGR@JBVETCP@TBN@RFPE|EXB\\DVFLDBBJBFDHBFALAFDF@LDLGNEFBHAH@PDHCJ@NGDCD@HBABGPIX@DBBþLLBHDFFXATFFEL@^DDER@POJAxPF@BAF@RBJFRALBHDLAHCH@HCJBdIHAp[LKNIPBHABA`BLEF@JCFBFDJ@HA\\BBAF@DAD@FCF@LFFCBCJBDAFDF@JBBDDAHBD@FILIJAHBFCFBDCDDFABCH@DDF@FDFAH@NJJ@HJF@HBF@DBF@P@DDVGB@@BF@BBDB`AP@DBHCFBPBPFFDNPHBFCDDD@LP@BCD@BD@CF@JAF@FD@@AB@NDFH@BlVPHplDFlrXBBD@`NVTFHh^JJJPRBDLDrBźZXH^\\LBGVELBªCvG|CfF\\@tJRBtN|@PC\\@JAD@@DCHBBPBªBbBVHL@ANBVFBD@HC\\CFBLDDPHBFRVLHJDLPBB°DjFfHXHPLVFN@PDV@NDHDDHTDFBFJJBd@XEPCR@T@^FJ@vKlBZCNGTFZCLAXJhAF@HFDABBPHN@dA^GbQN@JBPJXDFAFDJ@FDN@BBJFHADDH@DBHABDF@DBFB@BHBB@BAB@HCJHD@BBB@BAFBDALDVDHDNA@BB@@DD@JDBDH@LFTE@AJ@HCDDFABFDBDETADCHDDABBJABBDADDDADDNDJHFBNANGL@FANBNCbDN@FDDBREDBVNZBTD`NPDFAH@D@BHLFlNBDDDLEDDIPDDNCPEDAJBN@lNPHRJFTB\\BDNBNL`JXLJBDBCRDFFLJLJ@LHVNBVAJDHNVJZFVHXJdThLLPDLLPXN\\JJFFF \\pTJHNFRBL@ZK\\Gr[\\IrQV@NĔ|ÎǑ"]],"encodeOffsets":[[[81410,40830]],[[81116,41022]]]},"properties":{"cp":[75.989138,39.467664],"name":"喀什地区","childNum":2}},{"id":"653200","type":"Feature","geometry":{"type":"Polygon","coordinates":["@@cŕCsO˅BʡCˏÀ¿{j]¢yôµ¾¢wTQzÖĥZqdJ[HYPaBG@GCSCiGQFKAMFK@ONQBE@YCIJECUFCBCAIGKACFEZIBAGMBADAAEJE@IAGB[FMLABALQBUFGNQCIEMA]@KHMDMC«EWEMEGGIAE@EDGFQL]BKKoG[EKMOIEuWCC@CEIOK]EGOSOCKAIEMASEEYQGQ@IAEICsOCEGCMCicWQFKHEBKDECODKAKCE@CHEJDJCLABGHIFMBIHKHUBCFOJMAQBCBEFC@ILI@GDGBK@KAIJ[@G@G@CBA@MCGCE@GGMFIAEIGACBI@EKGCECC[uCmECAABORODGBI@SDG@SHU^eFKBM@YAESMAECOGECIIMC[BEFGHEhE`KHIPEFITOPCPUHCPDH@JELCZ@T@LFJ@ZFH@NED@F@DCAKFEFA@OBADADGHGPEDED@DCR@FCH@VKD@FMHICE@EDANGJ@JEbBRIRBXD^GJATBNJH@HETQLWJGDEFEHARBPCLGBGHGZGJBHADIAKFMJGTGFEFATEJAFBRAJOHW^YZ_JOFSBEESDK@CGMAIBQCKBCBKEGGAIIOCIKDEB@BCCE@C@CKMBKEQBCGEDIEE@EBCDANFLAHEBIDCXQNENI@CDEEI@GGKKCII@ALGDEFe@MBONKFSDEL@FEZHLCJB^A@ALP@JALBD@FAPBJCFDFBV@HAHER@PCL@PAP@\\CR@TI@AAGFCPEFIJKDEDUDGLCJBXAfGL@BAJMDMFC@IPIBCRAFEPA@CDA^ABAEM@EAC@EFEEIACJG@GHABEDELAPKRIhCBGJETAPERBJGDGHIRIJAPBNCH@b@XCJBFAVBJEHG@EAAIC@GJGBGAAOIEEDMGM@EHABAFKHCL@FKLKBCAEFCCGFE@CCGBG@AFABCGG@CHQACECCE@CFM@EC]ACKGACBCHGTEFEBCAODIHMBEAGBMLI@GDINIHQTQBCIBI@SHSHcBAFCfGHAHCLSFEPCFADMFE\\U[_aKcEEAECYAaMSKQCkMAACGCCWAKCKUCAYEQIWDCASOOEMCWSWC[MOCWAIBSFMAMAOEI@GEoI_M]GQCKCOBMAM@YAkQKG[GAEGESA[@_GECMEQAcIAACEDIAKBCFEjGDAFO@CCECAIAECACBSKQKMBKAEeGSEOGYKOOMGqSgUIKIGaEO@iIAAQ@KCcBOIGGAAGAGDEAEAEGIEOAYGCAIKCCIKIIECQEUBABCJCDMJMLGDKGQ@GAcWKAABCFG^GLKLGPIHIDGJIBKHCBC@KGUEA@CFIDQCCBAFCFGFgI]KWBUDA@@EACICUAOHQEUKAGYWCC@MEG@KICKCWAGC[@oCcGO@ILMDµBAOCq]SIiKQFKVQDYA_GaCYEGFDXDBBFADADUBGHG@EEOAGCIC]@EDEJGLEBMEOBEBELGDAgBIFQDSAMDWLSDWFkAHkVOLQDOEOQSMUK[E]ESFaHY@YFKHOHaZMLKXETINOR]LULUD]@QFQLGLCPUzSZARJFHJDxAbELQ\\MNMTBPFRJLDRMHQDaB@OFANKHMBiIQBIAc@Q@_JQGOeaOoaSGWFMPUN\\SHKVcP¡JmRWFiSWAWH`UBM@sKSIMOEYAWKWKOUCO@sDYGBQHSHOHGBU]_ISJ[AKMMOKSKUEwLQCGGIOQQWOOCgFWEIIAWEWGCaPK@KCSQwUYAaKQUOKK@ADG@SCMDUCJOMSAG@EHUAEHGACBEFGH@DA@GFE@CGC@GBGJIAMDMDABKAKKC@CBC@ECCICAA@AHC@AIGKCGGUECAGOUCEBE@IECASDGJI@_IIKAEECEGK[MMEASDe@UEOGMACCQGSAgL}NOAOA[Ku@WA[QqYYIUC@cD}AYDWAGHEBS@IEYAIEIBW\\CJBNFNBXMTEHU@KDINEF[LKHEH@NEJCFCBIBIFG@ICI@MDIHUEMEE@AJCHSDIH@BGHA@ECOQCAE@EBCFIFIAEE@KAAS@CCE@CDSHS@MDUEMGC_UDKDQDOC[OGBOVIXCRIRGLODwK]FSPENUJ]DGfAFcKUEaHmmAQCAPGHA@CCGICDCBEAEEE@KAE[G_@DI@CLANORMICKD@iAUBKFUXWHcMY@UFYJWT]HI]CUCYCSB@}HDVHRGLOBeLELAVGLuAGH_XUBQGWUMAIEEBIDEHMDMFQDC@CCGIGEKEG@QFCBBRADOAG@oPmHGLAHDZDLABCBODYOCC@EAAIC@CHI@CUEMSSMKUKKOCW@cAeBQEQI@ABGEKGIOMGKES@OIKBWEICWECGCBCJEVWTOHINIRGNSTODaPCFEjSGMAAIFMBgCECK@iNWBC@AKCAO@_DEEAMCGGIsOAEFKAG@ELCHCHIAE@CCAIBAAGKKEGIGQCCUCã¯G@GBO@WHYLE@CA[WMEU_CCSIBGDETQIaACGBAAECAGDIDEREDKACYACIGEFS@QBEDCXGBKEI@ECGGAH[EIDGIA[@]MAGEKCO@KDUEGEAKFO@eHYG]BDCAEE@GCCGDABKP[DENEDCCEECCI@IDC@CMIEIGI@GACCABE@IIACCAMMO@KEAIGCKGMDMBMBSAKJeaGMKaEGKHOh]BM@QIKM@GISgEOCU[kDKb_AOOIIIMIKGSWKIMGWS[E}CU@UEcJQJSES[][UCeCgDk\\oKU@WLENUNQGM_OKOESNS@UC£IkKqSaGS@WNWLI@ODsEU@aGIGUSOGQEWCYB_DMJKAQDMNMJINOD}OUKUCWIUQACIBEBAHEHBFCDYBIEUGCE@E@GM@QISGBCHIHEBEFEBIFIACCCFCJCDMNKBCNIBAIGISoNcRQDKJSJKRETMLKAUIOO[QQGACUEOBSLGLGPH`MXCBQJIFcFWHAF]V[LYFYCQDGBaZVVHFDNANMJiJSLKJGdEDVGD_FU@eAMESKKKKSIKEAKBSHEHE\\BnCPW\\IFFM@UBwUGCEECICOMIIEE@GBCJEfBfIR}V]BiACA[@SD[L[FeJGBKFIJEDIJAJ@LCJBLFRNRBLATINGRMJkH_DK@GDGJCJBhLZRNPTDZ@pFD@BOHeFIF@JIdeVAL@L^VHHFL@VCLEHMHOFYDUHSVyDP^RPTHNMjY`MDO[PCNACvCJKT_^SNSXER@TDbDNFEIT@JHFTHhXP^bZNRFBTNPDRNDLBXBLFNJLLJX^HDWDwBaCcIeBCGI[KKKBWVOXOAQEg@QOMAM@SH_TIBGEB_GSMAQHKHMLUZIJM@MOURQHifAFBBDBFBEXEDKAGAKGE@CFGPGNKHFDBFJDDF@HFFBD@FANF@NJXJEL@JLDZNHBP@BBEF@DFNBLCRCN@RQFGFGH@HFDN@HDTTFJIL@NKHCHOLQ@EFAFDLELH\\DDdDRCFBDD@NOHGL@FFR@BSVID@NDHFDDBRIF@DBHLDFVBRCBDB`BLKbMFAJCXDDBFAD@HCJGJGJKHCDGH@PD@HCFB\\ADCPEDABGH@HF@JNDFDLBHDJDBJLLHF@BGBGJBPLF@BADIDEHBHGHGAKIG@EBCHEBCFEBEHAPEFADEL@FCBEBWAKD@DCFIJwXaRQBS@KFGBIAOBYHGFCJATMV@LBJAPDVELJHBFDFFBNDdGJ@RFTABBAhBDHFJBJBL\\JHHHHDHBNFNTNLNBPILAL@NPLFJ@LDRBHD@DAJCDYLKJABAHGHc^@LCHGDihGPEHKFGLWPO@KFIDqCEAKIMOEAIBIDCBOGQ@GDEDIRGDWJSPOVQDIFOAEDADCPSNQ@GDAF_X@HZ^DH@JQVCHKLKPaRE\\@HAHKNOJQRI@MGIBKFSFORKAGAcJCDITW@[EK@UDQAQBe\\EJ@FBZHJBFCR@FLFRELDLBRERBFBVPNDJAPCLAPLJDBFJLAHHJDXDFLDPRJNXBN@PEJ@ZBHBHVCBMAEBBN@FBBvRNB\\@FDJHDHBZFDXDALITOTGDSBIDSZCDOACBOR_Pg^SBEDGLOJIHKTWVGBKHEJCXDHFJBLDFNjXJLLLV@JKHGR@PHL@F@JG`@VLHHDNA\\KH@NBNFND@Vd@HDHJJLFVPLTDPD^DFNJERMX@PAJBNJXHFPFDF@FCRRbHNBb_bCJBbIJILIFCDHHRJBD@JCPEHCDCJFN@FCDKFEHAH@\\DNAFCHOLQJQFMHOXED@D@DFHTRDHBHARDHVJRJLL@JKNFHLDBBIFAJDHBNVfF^VpBJCJ@HDLBRMnDHFF@FENEXFXFH@FKNEJCL@HLDBF@HAJBJNLFBXEJ@JBJDX\\BFNLTZRNHH@FKZAJNZVX®¢ƄƼ¨ǪǊĺĠľĦ`ZɴŘȄĞ´ƮĄbPXFfD~CJALEH@¢`HLDJFDFB`GXA^O`EL@RIbIbB\\C\\APGZOPGPCPAF@DPNRHTLRPJFFD^BTLLNXAbDJMVJHHJ@DCNBLDR~ŠÈˎ¤ȔͰƃ˸PҺX͂BưAĴBbAǞ@İBz@τAԤBɚC"],"encodeOffsets":[[85417,40431]]},"properties":{"cp":[79.92533,37.110687],"name":"和田地区","childNum":1}},{"id":"654000","type":"Feature","geometry":{"type":"MultiPolygon","coordinates":[["@@\\KPG^KFGHWDAAICICAF]WCWECCEGAaK§ÂRADVDvJXAHBBCHCBCDC@ADA@CJAAEBCLE@CFCBAACHE@CDAFA@AHCDI@EBCAEAC@IAABIEAAEBA@AEC@GDACEB@@EGCBA@ACAAEBCAEBEAEFGDA@EBAAGBKHAEEHE@GFI@CFIBAJAHECKBGAABA@CYDK@YBUA@MCK@IACAGEKBCESGGC[KmOCS@[CMQ@ă|č|ǓN@BRDDB@ZAZJVJNJHHDNJZ\\XLfdJT@FCD@HGJ@HEL@FHPALHHAB@DCFCNBNCH@DFL@FN^LL@LHPCFHF@DDBAL@DFBDDABEAA@DDCDBDCDBDB@ADIBQDKFIHFDABABECA@AHCB@CAB@D`EV@ÝŲAJfHnRFFH@RFNCJEefClJJITAHEHQJMVOHGPEHDFAPIDELI"],["@@EDBBGFHLNIEMABAA"],["@@UMXMLQJC@s\\IJHFpRBY²GCMXe"],["@@FjZT@LQCPXZGDFFCBDFAHDBBJFDCBDBDFEJBB@BBDEB@DABC@EDEF@DIF@@ABED@FC@@FCAAB@DEACDABABCBIDABEB@DABCBCAEHC@SNjJDFIXUDIFIJAHBDABCBHFLDHHBHDDFLHFJTEBDJOD_TOIEGSE@HNPAJFRKFEEEBDLgA@BADHF@BCHEIBIECBACMFIH@AC@ESSAGDWEUGWZOAfDC±XIR@HGbAViKOD@RqAANGPAHcKGE]VgZUXCRV^DPK@`DRBXNzDVCLD@BBCjEPEDCLIJCNG`BJCJGK\\BVAJCB@FAHGLALENCHCNKNAHOTDPEL@FCDBFDFVPFJHJ@HFH@FGPBFFD@HBBDBHLBPJRDBAF@FPF@B@TDNAFCJDDJDTPBDDJIFQ^[RAFIHQXOFMJINCHGH@HC@AF@BCDADABE@k\\uJMHiNcBIDMFUNCJWTMR@JBLGLSTQ^HPFPDZDCR@j@RBLF`R@DLBFDJDH@NGXAHINCFCBCACICCEDETKN@NB`LNBTAFGDEKG@EFCLEJABE@CJK@CFAFERI\\KnK`ENCJALCJC`[TEIrGIRCF@JDDBJLJBLCHEFAN@TFHM@GBCEI@C@AH@PIN@LCJEFI@GFIC@AEHEFALGRCBGGEACBKIGAMIEAEKEK@GCCIBGBCDATAJGL@@ID@FCTGDAACBCLGRHF@PDD@FEJALDF@FFNDFEJELBF@FGPGBIF@DCTANIP@FAFGD@@CDCTGTAFGJ@FC^EPBBA@EPMCEJG@CAADC@EHCBEEEBANAHLN@BDTDPCPGXNB@BEjAPFHCLBVCLEDEBA@CECDEFALABIDEJCPDFCNABC@ANADCJBFAHAHDLFHBJAN@HAJBb@\\IDEREHGH@HDFBLCNIXELGBCCA@AFGTE`ABADIBAXCN@FCHBN@NEJ@JEZFXEFCFBDCF@P@DFLC\\DjILCHGHACADKCEBENEFGCKIEAIBCFEC@AEQG@IKMKCKGFC@CCAFCBCCKIKBK@K@CFG@CHABEHGBEH@BAAEHAACD@@CB@@EFGFARFR@JITGLS@KBMAECCCBCAACQAGG@CE@CKE@EECIEEAE@ABCDBFA@IBGEEMCQIOAECEBCBGAOCGDI@_DABE@GDCBACGCE@CCIEO@QKSKKKCACODC@GAEC@AEBA@ECA@GEAICGGEUCACECAOUASEGBEACBGAE@GEQ@EHKCAEII@BOCEECOCCAAECCOC[KMMOIQCQJBG@KGGG@KO@GBE@SDI@CBCAIEKIGMOA@CEQKGGGCCC@E\\kXC@@GoJKE}IBY_GQYFQLGJGFOBQAQCQGMKIAiLIBKAMCGG[GEQAKCGIIA@CAEACCI@SGBFIBEAEGGAM@ECCBAAI@@EC@@CDAICE@CDGBIAAD"],["@@L@JHDBDCBGHETIDCNA@CFBP@NFZ@NITBJIF@NENDVAJCAC@EDAV@F@FCF@BJFB@F@@R@XDF@HEFAHEGAAIFGLCDGL@HAH@DEHAAIEEDCCGL@PCHJNFV@\\DJAFAJ@BACGKEBAAEBCLCICJKBEF@HCJBFAHBFABCF@CIBAAABCHGFCN@HAF@DAFALHRHHADCBA@CNDFA@E@AHAH@JCDABGJ@D@@DB@NCBEBCJEV@FDJAFDL@HGBAHElOTErGjGSHAXCXDH@TGHCF@HCRDN@PFXDJ@TAzQ~ILAZSHCHCJBNAL@RER@N@DCZCN@HA^DPBLAXCLIFAPBLFP@LFBBHCN@PFVAHD@DDDNBDBH@HIFCAEFGLEL@NEFK@MHKFIJG@CVCHANCBCFGDC@MRKNQXGLG\\@RCFETGFEDANBJCDAB@FADDD@PILBXMHGHAJGLALGXAJCRChCXGTBXG`MLADGDEHCJIHCDCBECIBM@GDCBCDCHBFE^DJFHENAB@JFNAJ@BBNJHBHAJBDBBFLDHG@AJCBETGN@NDPBJCDCN@FBFCLCFCJATFJCNADAAGDGFGLFJCNALLADBDHBDHFDJ@@CDAH@JDBHDD@HJHPBXMDCD@HCH@JHFFBPDBDDP@JDPElGHzF`Bf@RApMRAFCJ@VINDL@HBT@RDFCJALGPCDGAOHMD@KKCEEEHCL@HBLCJBVKLOJIt]NAPADfFdHBEFCJADED@FDHDHANEDFEH@D@DJDJAHBFFZJFDDHHDDDP@LCFCHCBGD@TG@YEGBIJ@DBJ@FBF@DCJ@TJLDDBP@ND^ARIHGJO\\aJI\\MF@LFHBLDLIFBLBJAJDPHJADBRRHKnSLGNMHGPGVEV@NFRJF@F@\\QRGRAT@J@^VJCDCB@FB@HJD^EJBLBFBDCFCVC@CBGFAFEFABAEEMCDKLMbUNELCRAPDLLJFP@L@FCTONQdKXON@fJHDF@VGFGLCDCGEHGBGFGDGN@T@RAAKE@SOFCBCQEKCACIGBCHE@CHCTCF@RCEMFCH@FEJ@DDDHH@JCHGLAJCJAJET@BEFINE@EJCF@NCJAJB@DD@TEHEJ@HFNFFLNBHAFKPGDIHAHBFAHG@KAAFIEIFGAIJCHA@CEIB@JAVFFAJ@FOHCDAFDPBFDL@DNTFBDHDNHHG^KBGFCRENBDD@FB@rDFBFFJDRITDPAJBHANDDAFB@CJ@HFJD@DFFCF@@FFNDTGFBN@LCF@LDPDBEBARAFADEFAJIPAPCFCVADBJ@LCFCJBH@FEF@CCBIEA@CAAOAIEAEBECCCCCGMGEEIU@UNQ^G`ARB^E¦mZ@vFXFV@DFNJF@DCFADIFCDKHIL@FCHADC@EAADG@AFIBGHI@GDCCEBKACB@ZC@EHEVEFDL@JH`DJAX@D@DIACGCBIIEFEBCCEECBKBA@CBGAELEDSNM@Ah]CE@ELGJKFALDPA@CCC@IEEBK@EEMMUDCGIKE@GGKICG@OGG@GAGBI@GDEH@FGBIAM@IDEHIDMEGBKAGBUPADEAM@GBCFHD@DA@IAE@@DDJIHGBCFQ@GGK@KAAGIBI@KBCEM@GHC@DMAAOBKDACUBIFCFQFCH@JKBCDBFEBADOJUDMHGCBKFEBECGAAMAAEQI@GO@EMFE@MACGAFMLARKPADEAC@GDCRAHCBCBAJAHCPCFA@ACC@CCCAAECCIKOBCCC@GOCECACOCAAGCIGACGCECICIGAECAEG_BKFGBEIGGEIDM_]oH[L@DC@ACAG@AADWB@FFRBDHD@JADATCRBJI@MQUCGCEGACCIA@AFCXCJAZBTAJG@EJADGHC@GFMNAPEJ@BABIJBDC@EDE@QBECAEAODCAA@CGMEE@MAIHICM@ACSDICK@C@KDA@IAEEQEEEG@QKEFEBOAEBIBEAC@CBIJEDUCIBMBGCS@IGQDKH[CIBG@ECAABIDAEIJY@EACBE@ICCOMFKFEACKEGBCHONAJMHCHMDUBCHCBCFQHCB@DHFHHCHAFADQDSNQ@IBQEU@ABADCD[BMAMHWAKCO@GAIBECMAMDSEAAACGAG@UFCC@GAASCEBCEEBAAI@AGECSEIPMGM@E@CHGKECKDQESCAFCBEFCAGFOEGBGAEC@GAAODADBDCDO@CC]G@GFE@EDGK@ECEHI@EBGAWFGDGFOEKBEPGLKDU@sIOGceWKS@YDkLYFU@aC_D}ZYF[KUMIDODOEMOKWSYUOUkK½XAMDMAEM@AAICAEMBEDKDSEI@GCCE@EOEECEBQAEDKDIDECU@KEO@IEC@SGAABEMIKFCHCBY@MCAAEEK@MACEUKACBEQGEDI@MFU@EDCFBJCFABGBWQGCYCQJECGAGCAEIGAC@KECC@EDBDADBBEAEDDDIBGBGBCGQGWU]E]@wAQCMIOMSEJwGaLKBSAMCQDQPKB_MMG]Ge@QCOEMBEBKBE@OEE@GDOBODECGIAEECWCWOGBIDGHWFKBICAKBIDM@KCCEAWAKEECEI@GAEGAEAOBMBS@aJOBSAOLGBIHC@UCCAGUKGYCO@UHKCBCEGAICA@EBCBICO@MDUAGCECAMDMCcJWHEAGEGA]DIFCDCDWJIDMFK@SAKGGEAMDIFIAGBKEIMGUBcAUSGK@QHW@YHIDIH@JALDL@NCVOBEFCFGDCHA`OAWDEXITEJGDGGE@CNCNM`SBCAMHQ@MNQCK@CJGPAHC@GDKCC@ADCLGBEGK@QAGCEMM@KLSJGLEMCGELOAECCAGOMAEBCAMAAKEM@IECGQGK@[LQ@iOOBSFWB[BeEcF[AEOYI[J[ZEBWCQK[@ICAGRK@CEMEGBMFGACEEWDK@KECGCOO@]CaMI@MF[H_ASHUFQASGeSGKQOMBgVSFCDAFMFG@CAAGDUG_FK@GGOKCGEKAQBMFEBUBK@ICIKCOCEGCQAG@qLUB@GCAC@EUUSMQCM@gLSAqDCBQ@WFEE@KJG@COGBEFE@CIKICK@ABMD@AQ@ABODGDCFBLGJEBOPGBOCKGikIIEAIGEGGAOECEIAKHEHQHaDIDACEEEBSCC@EDAHDFAHCHQPI@WKE@MIGOsEMBKFMBGAOOCAIFIAGCEGW@ECC@MBM@GEC@UKGDUDSHE@EBQTIDEG@MEAGAGBSAEBGGA@GBAFMBCOQFOEQAIBG@[gKCSAGBEDKJGJ[RCFKDEAGGAKKKO@CCKGGEAHEBMDCFCBOBICGBS@MGCDC@GA_BWAKHMGCEECAMEGQBIAM@OAAIHoAIFCNAFEBCCKIICQBEGAKDQCGB[b[TYJMBIAABMEIAiCECEBILENCDPL@DAFCDAFGHGDCNKFBDCTYNMJ@DEHEBEAAHCFCBJLKJKBQ@QMGWYCMBEBS@KIGHAFC@QF]FECCCUGYDGCKBIAA@BCACUOEFEDUQgMWBWHCDKDEHOLAHOAMDEGEC[BGD[HC@ECQBC@GEI@ICYJSFECOBQIEGKESLIDM@IFUDQ@IAEDE@QEO@MCcAIAECGOGIUDIIG@EBKAGEEGEIOSQBOC]@CAAABC@OIEWDGCC@QJC@KFCFAFSFGDQFKCMKCAmJEAQMMAUH[AQH]T]XE@O@EBGJGFGN@DBPPTBNBH@DOFADAFJJ@DGHSFGFAD@NADIBGFADLNF\\ELAJALDDNFPZNHVBHFTNJDF@FBJJBHA@W@OJCNCBMFU@ULINEPGFEHEFO\\IFGHKXCV@HADIJELCDIR@DDJHPBNLFBDDNALDF`XLDNNJ@LFRABB@HCVAPRfNbXtL\\Fl@HCL@FFBDCDDABC@ABABHDACDA@DF@@BDBDBHBADDFDA@EHAB@CFDBF@@CFBD@@AAEDCDDDAD@EDBBFAF@@FBBDA@AFB@@CB@DDAFCFBDEB@BHD@FAADBBBABEDBBDFCH@@AIEBCC@CAHIDBBFB@BAB@@D@B@BBAFCB@H@ADBBF@BABCHAFBCD@DFBFA@FB@B@BA@EDA@CLHBAAA@AB@FDBCBABDF@ADBBFBBBJ@AFDBD@BEHCFBBCH@@AACD@FBCD@DPFBBBDN@@BIBHF@BGDDDLA@DEDBDHBHAAEBANB@BCB@DJ@BB@DFBJAFGHAFBBDADBHRADDFBCD@BHBFCB@NLF@LE@FDDAFHFH@FCBAAGDABBDFDBX@BDBFF@JCD@HJF@BABKF@BD@HDDL@NFNCBDEBAD@DFBHABEBABBDFDBLED@FBFAF@@DC@@FCBDHEBAFBDEDAHA@JBCD@DIFI@IDGFQBmPYDIB_B_HGFMBkVQHGFWHOHCHMFKHAFMHE@SJGH[f@FADAPNLPLp\\TFhTbN\\RXFXLxlTP^DnRjF^BG\\SPGHBFLNPJFJ@XEbOPALBFL@PBRLfCNORIPAl@hadEJBLFZHXBNALIHQFAiFSHKLANLPTPHTzxDFJvBVDNFL^PK¢Ļƚ|J\\BR@fJJ@pPLHVi°G`CdPLPVHD[P@OHAB@FB@BD¡pBHTRLZTNBFAHBDBBFAPIPD@DCJ@BFBBCJBHADCF@JDrÆPdJ@F^CŢ]`@@IB@\\@LBAADC@K^@BFNALjAPHTAPDIBEAADDDC@ADG@EDEAIB@HEDILEB@BS@EF[JCAEGE@@KEBCG@AICIAADKBADKACCGBCD@FE@C@CKIEBEEACBC@ADIHGBOPCBGEABBDCDBBGBE@MGS@EBMLOEHCBAFABCACBUBGBADFDAFA@@BO@@BKCCLEDKBCDGB@FEBA@ACDA@AIDAABAA@CDC@ACC]}DACG@G@GAECG@HLM@NRBLFR\\HHHFBTDJAjKJBNLRHRDRBPAHEHIRKZEPIHA^MLIVGL@TBj@TCRIP@LFVBX@FBBDFBfªI@EESBDFBLDDHDHHRLDFB@NPJFBDFJ@JAD@DCJ@TAF@HLPH@HH@LAHRIRDPJNN\\LPDDDBFDBPDFDDFAPJ@FJDBGL@FFR@HBFAHBDAFFHBTPVDBDFDBFVHHJDFB@HDB@FABBFD@BF@HCDDPDBLLTLRLP@JFDDF@HDBDDAHCF@BA`CJ@HCPDHBDAFAFDPBRJNDFFAH@JEBCAAD@BBFFFDJFFF@DLF@@DHHRBBDDBDADDBFAN@LKTSHIJQ@QEEBEH@FA@@DC@BDGBBFABG@AFGHAFGB@DEH@D@LALJLDLADEDDB@DEDLHLDLN@JRHBFD@EFADBJJFDLEHMFAFDFALFB@DD@@BJDLBDDFBPAHEBDHAF@@CJBLCDENCR@FBFFTHNC"]],"encodeOffsets":[[[87051,45830]],[[82999,44999]],[[82607,44804]],[[82658,44945]],[[83404,45514]]]},"properties":{"cp":[81.317946,43.92186],"name":"伊犁哈萨克自治州","childNum":5}},{"id":"654200","type":"Feature","geometry":{"type":"MultiPolygon","coordinates":[["@@RvJzJj^RJDDDADBBFBDD@BGDADAB@DdZD@DDD@BBFB@DN@@DJBBBFB@DF@@BF@@DDABBABFBADB@@BH@@DJBADH@ABDDDA@DFDF@ABHBBBH@CDBBHA@BCDJ@ADFA@DD@ADDBABBBDAHBDBADJAADD@@BDB@BD@@BHA@BABB@@DF@BDCB@BFAFBBD@BD@ABDDDA@B@BH@DB@DFACDDDFAABF@@DFDDBHA@@AB@DFADDD@FHD@ABBBD@DB@DHDH@ADFBADF@HD@BCBH@AFJ@BDHBDB@DFFAFFBADB@LAFBDFD@@B@BNCPBBDDBAFF@ADJ@BDJBCHD@LABF@BCBIAGFC@BFAB@BH@@DDBF@FAADJ@DBDBBDJAF@@B@DIBCD@B\\CBBCD@BDBN@DDPCFERCHDAFCBCBEFGD@BBFNJCHCF@DNDXPEJBZRVB^rVfHhTCHQLGXMPADDBBDCDIHAHIVñ¶uDaDOIYDCCA@UBCAEBCCI@EAOP]Nß@QAMBcCiR@DGBCDELEDOCQAYFG@MCCCECQBECO@AEKEG@ICU@OEUKMAEEICSEMCEGE@GEICEAOCAED@ACC@yQEBCCK@ECIGBGDECCEKO@GEEACBE@AFCDMFE@GD@DGFCFQCPI@O@GHMDABS@CDGAABBDABGBM@BDADEDADI@@FCBM@CB@DA@OBEDE@IAIDS@GBMDE@CCEBZ_Dy@SHUFUB{JSFIFeTMLMNIHKFMJuZaTYVQTGJIFSTUNGLGRAJCLQX@\\F`@PCRITIHGLKT@N@L@PGJDLV\\HbQXKHOHYHKLUNcNOHCNUBqLWNSHqfOH_XcjIRCPDVFHRXHH^XHNFTDRCLBNFNHNLN^VNJHP@hE^LFRB\\HXDNLJFNBDFCD@BDLABBLR@HBDDDNLHR@RBhRLAPCRBJAPCNDNAHBHHDFHDXAHFJVXJHHAVBZNXNJLF\\FApPJHRdLNNJjZJ^HBFFHPDPRHPLLTXr^lCRDHLHNR@dOnaLBrR`BRCbBVDVHnF~A\\G\\AdBdAN@CIECHATJJADCP@JALNJFN@FA`ALCDCD@HFD@DAHEJCTLJCN@H@DEB@RAHBPA`JRAJFFBXGFCNDJAFED@LFNCJBJ@NDDDPE\\AFDFHLF\\EB@DDXDPAN@FDDBRCZAJFZFPLJETAFDDDJBVAFALBHHH@H@LG\\@xOJKHEHCPAVK@CBALITG@AIMBGlDTAPBJDd@NF~F~JJ@LDR@RDfHRFVFP@LF\\HFBJBZH^JVND@CI@AVnJX@lB^CTEXFP@PBN@DBNBH@FDPA@CEECGJYHCEEVE\\@VCVEVIN@RFPCP@İdNAZHhBnHdBtDB@FJȔJ@QęCu@]LKLGHGNOJENGFODEŔéCőgoŧǁAGþŵÕňǷ³Jm@_COEՃ܋DۏAMB¡@C}B@¯Dĥ@A{CaCI`E^JRDDILZjr`HLDBBFLB`GPFPDD@zJRdZJ~|xpVlR^jXDHNVF^D@DHL@@DFD@BTFBD@DEDHBCHDDCDBDHAHFBDHLZXJDCF@JADGDBBX"],["@@^GRILGX[NKp[`WDEPUN[BGBWHSVSfYTULKL]mLEBOAADAACB@FDLKAAECE@CDCBGABAJC@CCGBCFA@BEBBDDABCDA@FDDHGEC@@HAFFDA@AACGCAIGAA@@CFALJFAJIAIF@DCJAFCSAA@AABIF@DFBBBC@EICIAAA@AHA@DFBBCBEDCL@@CFCNCBEACA@CDCCBKAEBC@GJAFBAD@BBBHCFCD@@DB@BEH@HHD@AG@AJDBEECC@C@@FCBACBCHAH@VGBGDEDBJDDA@AGC@CLDH@CEKE@CHGHABC@ABCD@LDDABGEA@EJBJEDBBFCFDFF@@EDCDB@DDBFG\\FH@DCBICCCBCDC@@ADG@CBCRKBCEI@EAEIECC@G@ALQEI@ABCJGBCAIBOACJKAIDGFGDEJIACIE@CPKAC@GFADE@EHEB@FNDDF@@GN@FCJIJ@HCAKOQORMBy@QAwI@CMEQSCEEUWYcACDECKLBOECqPgBcRMDGAwEyRGJKPEREGeXCH^PAC_FAJID{FABQDAFEACGA@CBCFGACFKHUBKFIAGCI@EEG@MBAJ@FEBIFGCGBE@GBAAAJAPBDAF@DCFBTCFDPBRAJBHAPDJAFDD@@BFBHAFCLABAN@FCAC_UAC@AB@NFD@@A@CIM@AfIGGQMKQ_UOYaiCIGGKEmi{gMM@ADEICCG@EICACDEAGCEDEACCCBEMEFIHAF@DA@GBEEEBGHCDGJCBAACKAIBIAEBBAAHABAAAC@EBCCIBEGEACBBDA@GEEACEI@CAE@EEGA@ECEAAM@CGEAACGACEECCCIBCA@CIAGG@CFAAAECE@AAEG@EEC@KCAMEGGEE@CBAACCAKBACEBCAACDCKEGE@KAA@MCADGCAACGACABCACBAAKCAGBAC@ICMFKJEDKAABGBAAEBGCGE@IGGAAA@EIG@A@CDCEAI@@ADGGCFGAACAIFO@AAFEECAKECAEHCBCCQEIBGKICIMIBGFECGEGDI@GDEACAABEGE@EDEKKKCCMECEACAWBE@CDKDUCBCCAIEGIK@AEBECCMCEGECGIQIAADICGQBACAGAAMAGDICAGKICGEC@AFKIQDCPABAACB@NEICQDM@e@UFKBSCOFI@ICGEIOE@ODIGCQDC@CAC@CKGBCQAGBICM@AAAGOCCACIGEOCK@KBI@EBCAMBGA[DIASBKFG@G@ACCAWDUBKDGDCHDD@HCLJ\\CDEBAHMHQCE@KIAGBE@MMIEAIDCDUFCFKAMDEDALKBGAIKQDUGEGIDKAIDQBCFC@CAK@MEAACDGBFJAF@DIFAF@DGFAF@NBD@BMBGAY@YDQHGBEBYCMHGAM@QJAFIFDDCBICBGACIGIKOGBEAEKAGI@MEEEC@EGE@ADG@AOGCEKBECKGACICBG@CHIMCICEEK@ULGDGAGCQ@MCMNIFAFDHg^@BMNCTKFBFAH@DABALFDDFADEFJFAJHDBDCJC@W@IB_CIGK@ECUFGF@FYDA@BDALDFCD@HGJAHEJ@BCHBB@FCDGBEDK@GJCLEDCJEBCDGAKGCEU@WEuEY@¥n]FQA_B]HMR@VJVFFNHDHDDDDAFBFJFPBBB@DFBAJDDE@EFG@IAEDKDI@CAUBEDODOBIJEBCFEBQBABAFOCKCE@KDM@EASHMCEE@@DEEE@CICGEI@@DEACBMCGBIAOBSCQJICEEEAqCA@@ECCMAQFEDAH]LGHMGGCACSECMK@ECOACACAIFEPI@EBUEKBFJ@DGBIDBJEHFJEJBB@LGHEBGAGBCJOHELGBMAEKMEGEG@A@GFSFC@@CGAKBMDE@ID@FMFGPS@IFIBIDKBGHIDG@CGCCI@EFG@EDFNQDE@SDGD@DIH@BJHBDLDRFADEDTPF@BLQBS@M@CHEHAHGHHFCDKDEHUHE@GCeIM@WPcLMRSPEDK@O@IEKKOCQBKDMFaVKNCLNDFFABEBEFEBAH@DUDEDCDEAKAIA]FIC@GEAA@CDID]UI@S@QBQH[RE@E@QIMEU@UFOHGHMNKHmTGLQQCAIBOGICIBKAEAKJKCGAKEE@[NIJ[bIPGHQJ]BMCO@CAKCSII@CDE@EAI@CAI@AJFJADBRADUFAHGDEDKDO@@DFHADBDGJIB@XBD@JCB[JAPBLCfAZGRCLghMRCJ@RHTPVRTL\\BHCPKPIBIH@BHDHBFDTANFCJKJALEJHFBBCHFFJBDDLDDHNDDFH@DFFBAFDDDBDB@BDADBFFAFOLCDFHVRDF@FGFCRBFBJDJHJJJHBHHDPHJVTLJDDBFCJM\\EJAJCDCVFXxKTBv@LB\\ATFRBLDH@NPFAîWvCJ@\\BLHN@FGJ@FEHBHADBDAJGHEHIBCDELMFaVGBCDN`FX@TBlHlLjJ\\BRVnXjDTFPCZALA@BDB@BDCB@AAAABD@ABK@AFD@@DGC@DDBABC@BAC@@AABC@AFA@ADA@@AGBAB@BCB@BC@ADJ@@BEBDB@BGBCCA@BBAB@CEBAAABD@BBGB@ACAMBCB@FBBDADDIDACA@ABB@ABE@ABEB@DABC@CBA@FB@@F@@DGAEDDDABEA@B@BF@BBC@EFFFKDA@BD@DGAAB@BBDIFAHEDCHBDADGDCD@FBD@DCBC@C@HDEF@DE@GHAFAFIDAFCD@FG@@DFB@BC@AAADEDGBCACBABF@GD@BBB@BA@CB@A@ACAADGAABBDC@A@@CGBCAABGBADC@E@G@A@BAE@G@EDE@ADEBMEC@EBC@@BI@@BFLCJBDED@FEDEBEDC@E@AFEH@BCBADAAAFEBA@AAKBBA@@IDCAEDICABB@@BCB@@CDIB@BE@C@GCADI@EB@@BB@DCBIAEBCAACAAGD@DCBABG@CDADC@JJ@B@BEDEHODIBIFCLCFIDKDeDSAoAkBT@BCBC@CAOBICGD{DHĥf³Xûl{TcP£^§fs`uTtRMhk^[XCJSLSNODJJ\\ĺ¯äĉƓÞ@`]ÈZfLPFRD¼JVJFNDRCpEPMTETBRPXBfEnHRVP\\XNnAZCPHdN´ƤúŢĲǚ Ė^àĂ¤rCv ĞXFDDRJf^jpLLDNJpRRHhRTDbJTFRG DHL@dEnRdB^GZD\\LTLV@PKXW^EdCTUF[FC`ATSVEfBdDXHTKRKPAVB]`QJMb_T[X@ZNjNLGHKVGHMJGfBLIliPEj@NI@MEK@CJCx@PMNG\\AdEbAWDIEURCfVpF`A\\GfQfCrUVMn@TIDOP@\\HLIDQRCR@JP\\RXF`OZPVBVQtQ`EXEjC|DbHJDZHjXr^JB`KVAVHLIPCRLRFlQPAdH`NLBZQVEX@XD\\\\@VERSLGNCtWTKVBdtH^BtCVAVLZ@LIXThHX@DZSLM`[\\O^EfEjSDKP[PSbUd[\\[hsTCGCCEGGGAMBMCODIBQAODKBgQQAQ@KGCMCCGAQ@AKBACK@ADCCEMAIEMKWC[GQAKEF]@gGOMI]UKMGMEMAMDKCQESGM]WGGQWEGCUDOJQdi`WPGreTGXMrKVADMPGdMVMLKZGPGLGRWGaU[CKHI@O@K@MLSHKJGJSDQ@OE_@[RWDKBIHQHKVMTSJEHIRSZUbSvYNILEJGNMNKpYTElGfCVETGz@`CYFADDF@NCHAT@JCJBF@FCPAB@@CDAN@DA@EJ@BCFCBCACN@HABAACBAHBDCJ@FBFCNCHGP@J@OECCIOCMKoGMGKCKaECOEWAYKA@@KCABGCADCIDHII@BCAABAAAAAE@@GE@BAACC@BA@ECAFC@AA@E@CAFC@CCAHEH@CECABA@CBA@EBA@CL@DCCGFAGCPB@AEAACJ@@ACA@AF@@AECG@LA@AECC@IGPFB@BAHH@@@EDBF@@ACGCAE@DCBCACFBBAACDB@@@GCAC@MDDACAFA@ACCEBAAI@KBACEBACC@CABCHBDAACEB@CGEBCC@FADBLABACABAFC@DDBVCFCBCCCEBDCEEMCEDCLG@@GF@HEDEE@GFAACBHGGC@@HBBAEAKAAAX@JF@AAADA@CH@EEGBGCABAFACE@JC@AQCZCCEFAAAAAG@BCE@BA@ACACBCA@CIEADACIDGCBAFBHEFG@GC@BAKFLIAAE@DAACC@AB@EEDDCEAAC@AC@@EBA@ACBBAOALAHC@AC@BCMACCFA@EBCAB@AMD@CDABCBE@@CB@ACAD@@ACAB@BACACB@ACAN@@AGABAEE@CA@DAAA@CCBBCCBEADA@@GAD@AAH@BACCGBEATCGCAACBA@DA@AKBJA@ADAAAA@BA@AIBGBJCACE@D@ACD@BAG@FA@ACAAAEAAABCCA@AAAD@CEBAACECCA@AC@AAC@BCGBFC@ABAAADCE@DCE@DCI@@DABCCD@@AECC@BAAAA@@AEACEECEAJ@B@@AKCODFCGA@AE@GA@ADCC@ACA@EECAJEACK@FA@AB@GA@CA@@AEABAC@DCG@@C@AC@EDBCA@EBBCFABCA@EDCADAAAC@CCEC@AE@DAACG@@AGAD@@AE@BCC@AAGACAE@@CEBACKACCE@CB@ECBUQG@@CYI@CCBEA@BC@C@@AABEA@DSDG@CBG@OFC@@CIAAEM@ADBBEDAAQACAGAE@GCKAICAAFCE@ACC@IFE@EADGACABCHA@BCOICGGECIEGC@ACCBMGAC@CEC@EECBECC@AEEAMEEE@DCCCC@A@KCCBKCKEA@@AECIAKBAAEBAAE@AAC@C@@EICK@QFCEGEMJBVDFOHIBKAGBEDAHULG@CAACBCCEKEMEDOACBAJ@\\KVWBAAADE@CBEAABC@AEBAEIGICAAC@CCG@EGAABAAAG@@CCBFECCAAC@@AECBCDA@AEBBA@ABCC@EIKIB@@AC@CFC@@CBAA@BACABAAAC@JGCABAAAC@ACIE@CCAACK@GCAGFGCA@CFCEA@CAAHCDAACBAEABCAABCC@DAE@@EDCI@AACADCAA@AA@FEEA@MCABCCGDCCAE@BGC@KAHAFCECEBA@AKGEAIDECECACAAABAACA@CDA@BCAABC@@K@ABEA@CCCG@AEC@DMEIDAICACCBC@FEQ@DCC@GGFAACDCG@CCBEGCADC@AAA@CAAGCBHKFEKDEAGEBCACDA@CA@BCEABCKBDC@IAEACCACGEADAEAMS@Ag]QICECCC@@AEAAGEBDCKEHLNKDIdYDGHGZsTMXSZSeűEACEHCFIGCIEuOB@]AUDwAS\\AHÙsBAA@MVKNIJQrSBIHC@C@@EEC@@CBAB@DATBNGDCLAD@@BDBFCHMGEAEBEFEJ@DDDCHALEPBBEDABIFA@ADEBGBAFAFC@A@GLCFGB@@GFBBCFAFDB@FGHELALHF@DRHDF@¤FbU@_F@CBA@DDABGB@FDBABAECJGLERCJABCA@ACDCACDCCCB@FBBACCEA@CBKCA@CGEDEGO@KKKM]@EEK@CDGAMDMDE@CBAGGBKGO@EFK@GHI@GDC@EISecWKY[MIGCIGIMIUBY@YCAQC@_@_BK@WHaFGBIESBANMDI@OFYAMFM@EMq@Q@EOWESGIIWEKSWY]MKOcHCD@JF`PNHjZJHNHVDL@F@LELAHDADHBBFFFJBLFNAJITBLBN@RBFBPJ\\DFJT^FPDBBTAPDF@D@DBB@HBDCLDFBLDDHBDFLFFDFNBRHNFFBDAJVFPHDFJFNFlHjDJAf@MBBDP@LAFDF@DAV¶cH@J@DN@\\DTPLnD\\HHFTADFLBHBD@JDL@NVBZAL@ZC@DABBBAHDLGFIBABEJ@DEJ@HGFFFGBALBHAB@FCBEHBFAFBFADBFDB@BABHD@FA@DFCB@HFD@BABBFFBAJBB@JBDBFAD@FCJGD@BEBCB@DGFBDABED@DKFADBFIB@DCB@BCDADGDADGAWBuIUCCBÁQL¨BbFHDDXFXDE^DBDJBJCBGXEH]LOH[LxRTLCjEBCFMFCDAFGJIRCVBXRXDTIvVv\\fX drV`ªpNhCLEjI^RFFBFBFCNGNEF@DDJCFAPEFIDGH@JCDDzD\\BHLVF^c`uAnG^JRd`XdHNFVFb@RbD|DBĦ@°C@~AD¢@NABQAKD[DsCʑ@ËĨH"]],"encodeOffsets":[[[87658,46785]],[[87841,46002]]]},"properties":{"cp":[82.985732,46.746301],"name":"塔城地区","childNum":2}},{"id":"654300","type":"Feature","geometry":{"type":"MultiPolygon","coordinates":[["@@PIRCJELAVDlPH@HAHCRclI`KdWlGPODGVWNGZBPH|A^Dx@LBPLFALEBG@GFMLEJOVIhYTGcVSLUBI@_LAVENGBABSRIT@BRDxNT@RCLC`MZGlCZHjRP@TBNPHZPJRF\\DfHH@PAN@XLJJJRF@NAROREbBLBN@XA`GxGLBzTRDZ@jEdKJEJMFMBSKkDUNSLElQ`GFG@OEWDOFEMSFCTYAYPcFSHMLEP@XBRHHBIZ@XBLDHDTD`@dGVAfDNL@hARBVDHfEPAX@|KZCjTJAjcUIOFDQ|w^U`a\\AFZEpaXCVHT@ZUtGWVI`QxokJUEMQHQvsNaTYJe@O\\S`IDMHyASQEKUF]ASPSIPKX]KQWQQWNKBOgY@MncLOdDOP[TEPSAWBMHI\\GNMHUTYnWFUPSfEJKE_dcj[NU`cPMFOxgNMF]JG|F@nSRQvY\\GJQ`YGc@OJMN[LIbGJIEwIMIQCU^U\\WXITO@kvELIB[VUdgOsGOK[[»IwGZBPSHUGS[_AaOQ_OEIHGCIKIAMGOAMBa{qYÁ£MSYGDW¬ÇO]·LMRIfiFOCG_XUHcE__WcWysky¥«iw}sSOMk×QM@AWDMƩÉM]IMAACEu{IIGKqyIOUYOOKOQQCEBGCC@GACUeIM[_}qKMicYkK]KWEQEKCQOQASWMSSOM@EFGHSAGFUNGAEJGICACBGCIJKCC᝵@@ˢFՄDP@`E\\CV°ŇǸÖýŶBHŨǂhpDŎ@DœêCFEPMHIFMPGHKHKL@^DvRĚE@IMEjMÀGJDNFHBFRLRB~PxVVF¢Z PLB^BZJtJPHhL\\LLDPHNDNBVF`D@BBBDAJFH\\VtlF@ZCb@PCvBPAZ@`DTG¹cHKLIFBBDFD\\@LADDCBBBFDJ@FHJ@NHRBPFLBJADCDE@CAGCEAEMO@CLLJRFFJO@MCOOUKOSOCIIER@CEGGmW¢hWXIdCXIZSNCZBFATORIRS\\OHI@EACBCTKBERMNGLDJAFEH@HENALBJCPSJGTAJCFCELCRCNGDCDAbGFBHFHBBEFBTPL@NITAPKJ@JCT@F@JANA@AFABAH@HCDCJBHAPGdAHCJBHDD@XDLAPCTCHCDEASFAXGL@LFDDLDNAJGL@RE@CKAAABCFCF@JDN@BDDDRCBDHB@ACABAJALERDRJnN¶JHBBDBJFHxZbDFEFAPJPBdIZDNîBDLBbEHOD}FCHGFsV[RYXGDKFKDGDIBAnBRJBV@xBJCF@FDZDHJNA@D@V\\PL@DDDFBAHBHBHD@AHBFBLDF@BCHDJXLRLL@TFHHBDFDFFPTFTCF@HT\\DXDFDH@HLFDFAFFHDJNVBHHPFDBJHLHRAFBDFHJFFHFDDFLHTLV@NHHJBHERBL\\NPZKLCLB^PD^@XDNCJ@HCV@\\JF@PCZ@D@HFQ@CDBD@@EFGCE@EFMBCBWB]NMCAB@BVVBD@JAHDHDFAJ@BIHIBM@EHUHCD@D\\P@FELBFTHH@GLCBO@YFGDKHBF@JKJUFGFaH[@IAGC_DG@MCWBIBMJOFEDOH_JCBEJBFAJHDPBHFHJPLLDLH^PBBBJFB`PPFR@LDNJDF@HEDIN@XAJYfAJLhAP@XHRHF`VdPbHRJHJVHHLLDHHXDBBBJDBNBRFJBLAXFD@BJFFN@JF@FB@"],["@@ATEFAD@HFNADFHCJCD@FDD@DEFFDAFBDJDRTJFDB@BHBDJFDJDFJDBP@JBDDNHFHPBPHTFDDZFDJJJJFDHEJDFEFAHATHTNPJDJLZFBBBJBBDDFBHDH@HDZBjCJCf@rFVLL@FDJBTCJ@HCNCTCTAPBbHNATIXPNFLXHBEPCZOAVCdcTQfALNMì]PIHKNKPGTCX@XHRJVFPDVDbLPJHLAJehHRLDXFh@vGN@TFPH^FvCZBVFLBLAPBRDJFLTTNlJ^@tQRBXDLNJ@xQ@sfBLET]HOJOFMGK_QCGFIFINM@CAEGGMIICKGCGDIJGPIpCTIDKCuFGdITG@ImMUIMIHKBI@GOGWAYDUDUAOA_]IGACE@QWkGWDOLIL@rHJCJM@G@EDODCXGZKVOAGSA_@ECAC@EbIPUFARC\\DJANFXGt]uFAFDRXHDHBXGhOWr]PSBWDC`JVDNCDMEMMQaUEE@IJIHCAIIK_QWGaEkYAODGVWfM^EcdCxD^@PCHGHINWHGF@PLJBREdWbaVG^LLHLBNKPAh@HAPI¤[VGPCZITEHGKY@OHM¶uVMDCNGLEN@XBZL`XZFTETKDwHINEXAvDA[BGZI\\ILIBOISUYQQGIIQBMjcDQFM@KCK@KHIHIJCZKROH]DEFCA@@CIGM@EEAIC@WEKBIAQEMACAAIAAWCGGKCGKUGGIQIaGcO_UGEGQ@WBOKgBIZeBI@WJMFC@GCEMIKCQ@OE_OEAAIAA]OKGKCOKGIGEOAGCBIAEFIDA`IPGFCPENIJAXANDH@`CHDJB\\@bGHEVELI@IAELGHCZEP@DAHKG@SGAEFK@E[O@CDCVGFGN@JAJG@ABICECGBG@IACUU@ABAND^MXADANAFEF@HDFE@@ACDCR@GEC@Y@ODE@[IU@GDI@MDWC]@OCA]DKLKOY[MAKFQAGGIMGU@SKKGCEECEGIEEGACBEGQGKAIECGOAGMUCIEGBECEKE@GCGCECWS[@GDEESOSEEECACGGSEK@QKWKCIDG@ACEAKAEBGC@AGAGBGEACC@COKU[C@B@IMGa@EDEAI@wAUIAQBmJAHCLCLEHCZW\\QtUHEDG~EPCDCOKOG[AeKcAsASDQJQXG@ECISGC_CeGLV]FQH£^gJOJmR}dY@SFYBc@SJTGFsNGBQAMC@USEACWKC@[LIDEFIJOH@^RAHCXEXB@DTEFJI@OL@@HFBDSJIBC@ACCGO@EGCAK@AB@BFJ@DABC@GCG@IHIJMBCBAD@JABCBGACGG@ABAFYAICUNAAKKLGDGHCFALDNG@gOBADBLȍ@JFDJVTPRLVBJ@NIPEEIQKK@DLLJR@J@DEDMDMCAFOHIBUH_CY@OBuAODa@YDE@sk[UEGICBAA@A_CUEMAMCOGKC[KgKOGsIYI]AKAOOwOwU}OQAQKAEEGCMHIN¿FiNJȗEIA@sCcAmGgAYGMBįcO@ODQEM@UJUFUD[@UFFFGDIZDHFF@DOBECG@MACAM@OAO@WESF]DkAW@mIU@BDJC@UM]IYGIAEA[GKEO@UEQEeGQCQ@KCI@}I}EMEc@ICOASBkCAHJN@BSHKJAB@DULOBGDGFILwP[@KHG@G@GGKAEBUBIACCECSBIFOKYEIEYBQDCAECM@OBWCCCA@[FKEEGEC[BOFCCMCI@IAMDKEC@EFIBMCEDWHEAIEQB_IOBGAQBA@CFG@M@IDSKIDGFCBC@GEC@CDKD_BEBM@IEKMIBO@CDIBICGCI@FDDJJBBJEdFTAFDHFJBHTXHFRHHDBH@NHLXLJH`T`ZHJPHDFBHHNBJDFNHJJfRJLDFAFBHDFAFADIDCFBBJJBJHJFJBDAHJN@HKTKJCJQJEJBHDHPJBFB^DNAJBFFFLBFFAFFJALABWRCFATBJCHA^GJILINGFIFUFWVGJGPIPYXIX@BBBBHAN@RHLFZ·͐U¤GDGFBPCC@DNV@FMZCFMBAD@DHJAHBFADAHLBDDAD@BND@DCD@B@DBFEF@FED@BJF@BADD@LBDDGF@D@D@HHF@DEBCDFHCD@BJ@BBAHEH@BF@BDERDDD@HEDD@HJDOHCD@DFHHBBBCFBBFA@FFDBFN@FRFBHHIFNFCDBDDDEH@FDBFADFAFPBTPF@TEDBDDAH@DJD@BCFLRBDAJBBF@LFB@FDB@BCDDBBCBDFADBBD@HEF@FJADFDEJDDF@DDPH@BGFBB@FDBJ@BD@BE@ABDBD@BBAD@FDFCB@BDFFBBB@BFFCFH@B@BBCDFFED@BDFEFDFCLFVNLBDABBDNJBD@FHF@BEB@B@BFBF@NJDDBFDDJBBBBFLHBFFBDHJ@ADHFFPDBH@PHLJPBHFHBXENDJ@PFLFDDJFVBTDLAHDLCZ@DDRAPHL@JDŚFAÄEjAER@JAND\\ZJNHDRAJCD@HNNHDJFJXLBHFH@HBBTAPEB@HBDDBDFDB@BCHCvBRDBDDLB@DABADKNCVQHATAð|FDjL¬fVLFHHLFDHJCNBHADCDAFJDDHFHNHPRPHHFDFFFARBFDFHDHDZ@PBLFFBH@LHNDFF@JHBHJALDJDFXPNFFDf`DFHDHHHDFFHDNJ@FRX@FK`CJAHIHY`@NDFLNBF@FDHJJ^HjXVHDBDHFXAHILKNIHMHKDEDEHIPEDQH]HCFBHADMNIJEPIb"]],"encodeOffsets":[[[90769,49339]],[[88817,50116]]]},"properties":{"cp":[88.13963,47.848393],"name":"阿勒泰地区","childNum":2}},{"id":"659001","type":"Feature","geometry":{"type":"Polygon","coordinates":["@@eJ@BJN@D@BC@MEA@@BBD`VBDEDM@ABKBEDGBEA@AC@ECIBOCGBIAQBOAECSDEACDE@CBOAIBBBAB@HAFDHEHAJEFI@AB@NFH@FDJBHEJALGVELBDEHAD@DHBBDEFCBAREBC|IJEBD`OBG]WDHfQFOFILQHFzBxHNCdQhArOFDAPLKFDDCdBXZFVDFRTNF@DxJRBz@NAPQEGACGQBELYHI@UBK@QB[HS@GBIAGBEToASCIBM@EGOEE@GCEIIACCUFUAQBI@CCAAIFS@GDQBGCOI[UYAEBKHI@OEKOMQ["],"encodeOffsets":[[88163,45185]]},"properties":{"cp":[86.041075,44.305886],"name":"石河子市","childNum":1}},{"id":"659002","type":"Feature","geometry":{"type":"Polygon","coordinates":["@@MQaa@CMOEEBCQ]QgEQSiQqMWk{UQk]MOCG@GFEJGVG^ELKJEXKHMBQTBRIPSHSĞƙ\\WnaĉAĵ{͏BąE_K¯ǧ@QZEHSL@DADwLODQ@KDUGGCKKEAGBCNABEAEE@MCEGCA@CBAAOEA@AD[OăwiILEACQBEACB@CA@GBCJCDBEAAAHFABEFCLB@DCBI@CFEBE@@CEBCA@DF@BBIAQIABBDA@FBB@DFEAABGECAKFA@BCE@AECAAHDDDBDAB@@FBDNF@BABIEEABHH@FDQAOEB@AEBABBFCD@@DFBEGCBCCA@BB@BG@@BG@CA@BCAABA@EFCFCBEBBDIAGD@BJBEDBD@BGBADKBGCEBEAEBABFDFDAABANFRCH@BBI@KDIAGDK@CB@BIAAALCDAI@CCBAGACD@EDAEAUJKBF@JARGB@CHAACB@DDBBCBBHCEFAHI@IPOCEDCHBBNDHHHDBFEB@BLDJTHDAFBLGACB@BLJFEJBFCNA@ACEF@DDADABFHF@BGBFHFFCBBDAF@DBBANADABDD@CD@@HDCDEDADA@@DL@DDH@DDADKDO@SAOBCACBAAHHDJABCACD@BF@@DCBBDEDDBBBDDNCIDDB@BADFAFEB@BDAHDCFABCFBN@DCDCH@BDNGd[Lw@Q^DDCDGBCNDHHB@BGB@D@FDDBD@BCD@HDDDAFDBJGBKF@FHBBH@HH@FAJBBDABGDEJEJFBDA@XbIBKCWBSBKFKJAHFVAFGFUHCBKAOJMBIBCDBH@VIDKBSCEG@GGICAMCQB@BDF@DDFEDAFDNHH@FKNEDEAG@KDCDBFIBCHEFMDGC_ACAAGGCIASEC@ABAFFHBLAD@BE@CFKJI@CJIH@FIH@BBBEFBLEJADFJXFLFDDBDHFBD~^@RLAPBFJJF\\BXRD@FNvhREL@pBVFbB\\GlOļŴGǂÄG¼hÒgÒtˮĨPCZA"],"encodeOffsets":[[83850,41924]]},"properties":{"cp":[81.285884,40.541914],"name":"阿拉尔市","childNum":1}},{"id":"659003","type":"Feature","geometry":{"type":"Polygon","coordinates":["@@kKe@gD[AKKSYEG@IMMSKU@gI£UCEAe@S@EQCIOcAeHAED_\\EJEDKC[KE@YJLLT`BFEHCDaK}MgAU@MDGDCF@FBDDDLDDDADIZDD@DEDAFYDGLIBCAUJ@DFHADKJIHEPCT@DFDhPv^DD@FBDNHXZLDpPHN@FKL@DDF@BEAADFD@DB@H@PLH@HCBCIS@SFE@AEC@APIJK@KCMCGIECAAKFETFPCHGJKNI@ECMGMICI@ICBAJKHMEKGGSEACAADKJGRUFQNOFCFBHLRDDDBDBHB`H\\NTJDXFNSGE@CDAFBLNNIHAFDBLETIPIjATAH~@Fhú@BFFDCFJFAH@BHFCHEDQDOES@SDK@GBUDMHWHMJOFELDB@DRHRNBTFHDBV@|TN@HAJED@GTQLCF@DFBBBADWLODE@GAC@MVNJZJ^N`NBD@H@FPBDXFhDJDBBIVMRCNORELAHFF\\JLX@tLÂN^FjDÚX¾PzJòVJF@LI\\]\\Wji^[hgVq`«LkBM@EIIKEO@OBUHoLG@³`aHc@ÃOÁMO@AA@E|{BICEGIMEEEAGBEHIPAXDDNLGH@JADAAYKBKACCGCQB@AGBEAK@ACKCGGC@M@CAACC@EEA@@BCBCDA@BCA@IACCAISwMmK"],"encodeOffsets":[[81092,40674]]},"properties":{"cp":[79.077978,39.867316],"name":"图木舒克市","childNum":1}},{"id":"659004","type":"Feature","geometry":{"type":"Polygon","coordinates":["@@Lh@FABBFIJWTDBJJNVHHCPNPLN[XBDEFDFDBBB@JB@BF@BE@BBBDGBAFBBB@DEDDHBDBCDC@ABJJGB@BFHFBBJ@HERDD@BC@@BHBCD@BDA@DA@BBGDBBB@AHE@AB@DBBEJD@@FEBSVc`[JDLAB@BH@DHEAADBB@AFBED@BDBL@BBJDGJwjubID@BBFG@BDADJJ@BC@AFNHED@DDLAF@D@\\@DCH@FBH^P@PADJJ@FCHFLCFIXAPCDGDGHAD@DBBDB@CDADDBDKDCBF@BFABG@G@CB@DFBBJDDADEBIECDGJJHABGAAB@DCHHFEF@BEBEFAFFVOJGAAHQBEFWDKJFPBBÒMB@FDF@FENA@U°@UjEHLJCHEVBF²_BGX_`uJ@@GHMAGPaEOIODKFGRA`IVOJS\\EBGDGBODMFKDI~AAPE`UGÿkcDUOGLQgYAAcYIBCDAFQH@JDZBBBDPMBFJCDGNABCESMCGBOCQBE@IDICC@ECCAE@CGMCIAAGBGY@IH@DC@AEAASEU@Q@@NKBBHECABIFA@AA@@Y@AEB@DCBBFKBECFAC@@CB@@EGAAEIAEBCAK@A@@EC@ABABACO@@CG@UGIAMCCC[JABAFCBACKGACOA@@BE@@FMBBKE@ALG@BLBNHrLn"],"encodeOffsets":[[89605,45125]]},"properties":{"cp":[87.526884,44.167401],"name":"五家渠市","childNum":1}},{"id":"659005","type":"Feature","geometry":{"type":"MultiPolygon","coordinates":[["@@ºdLAPGBEKCQAMGI@EGI@ECAADACCKB[@ECACEAKJGL"],["@@Ǽ@AKBCPA@hMHKCEBGDCHKHLLBBVMJDZBBEBAH@DHHBDABA@IBCDANAJIJGH@HDD@BA@CEI@ABAL@DBFHP@DHBDD@JATIACGE@@PKJ@EISF@CWAWFGDQB@]PGJIFEJC\\K\\LBDTF@VNDV@vMJESTId@ZATEZ@~clONIFCfG¤]RG^EUKfH`DHDJTFDH@RWRITCtBdBfL\\BPHPLBCBEAOAKCKíACMJYAcIOBOFECEawYEGAIACGAµImMQIQCKFIBABDB@BGAACQDCCACM@ICE@EDADBBLB@DQFK@IHMBKCCCKEK@WHEBBTCFGDSDODKBWCC@GCIAGDcBOHGBIACDGDG@ABEB@BMBIBE@S@IDI@OLSBMJK@SOEAAFGAGEEAaHCBCDMHQDKDFEDIDSBIHOTIDKAMBGFG@EFIBKCMHQNAFSLADBD@FGJ[PQTQJSPEBYAMDYTWJcDWJgX¡nXHHDF"]],"encodeOffsets":[[[89581,48550]],[[89658,48494]]]},"properties":{"cp":[87.824932,47.353177],"name":"北屯市","childNum":2}},{"id":"659006","type":"Feature","geometry":{"type":"MultiPolygon","coordinates":[["@@HNZGfMMKyT"],["@@BABCDCPCLKDA@CHMHAHG@QDaDCCE@CDC@GFCDABCPCEABCACCACADGDACCBCDAC@AC]@EArmCD¾CťG^ŏMTâ¶fÖlJLHtJbøkYĎsfCXUrWDC@E@SKCAGQACC@IEAKACCC]GMcaAGDA"],["@@QwB@`uAAewGEBQPQ@CLEDGBMBUAME@CDCJC^@@Gi@]EACBA`@BABCCAIC_@APNJLF@FABE@GCQQMGkAEBCDB\\SAEDBjX@LnHDd@VEVIREVAZBTA|IN@XEbAFXCPGFC"]],"encodeOffsets":[[[87459,42949]],[[87800,42758]],[[88167,42802]]]},"properties":{"cp":[85.501218,41.827251],"name":"铁门关市","childNum":3}},{"id":"659007","type":"Feature","geometry":{"type":"MultiPolygon","coordinates":[["@@HCDBDABB@ADABCDGBAAAFB@ADCR@FAFBRC@ELE@AG@AA@ACACB@D@BI@KDECE@CAM@CAGBEAKDBDE@E@ABEA@AGDBBX`@BB@"],["@@`MZABEBQI@B]CkUOOO@WBMDGJA@AAEBMOY@OocJEIKBEMUFCBDBDJUDHnHAzfTElZNNNDPJpEJHBFQRGACC@@MND@G"],["@@ƀ_½ƏnABBBCBLNFDDHFBBHAHADBBABBDEJEFKH@BDLED@DA@@RPJJDTJ@HF@"],["@@Zr`CGmq@"],["@@GBFJJAAEC@AC"],["@@S^fLhC@GCKCAqO"],["@@KABA]IIVbLPS"],["@@BEJCDEBYDCDEXGlGn@CA@CHE@AE@@CHE@ACACFEA@IF@@CKABCDBFA@CACBCCE@AEBCGDAECCDECGBGCC@QEACHC@AMGEDEAAADA@ECCBCAEOA@@IEIBGEDEAEACKC@ADCBCCAABAABAD@CCCA@EOEGCE@EACBCAHCACCAGAC@AAB@@CCDA@CA@CGECBAAACH@CGEBKGCDIACG@EFCCCIA@CCAE@CA@CI@ACB@@AAAEACBABA@CEE@G@CEC@ABE@AEIAAAFEDBDCAAA@CBCEC@GDECCAEBBFABG@CCEBBDCA@BBBC@@ACAAD@DF@GZRAE\\GAI@ABICKBEAMBABM@@BGBCACDA@KHC@A@BBCDC@ADEBABABG@CD@@E@CDA@AACBCAMAACMDC@@DABACCBGACBBBB@BBGAI@ABDDADCBCAIBBDA@BDEBBBADACCBBDC@CC@@ABC@@BABEBAABAAAEDBBE@AB@FYJCCE@EDE@WJKJ@BQFEBqHS@CH]Jyj½W­ZKDFEFA@CCEAGGK@ECBE@EDaUfVKHJLJATKVCXKrfADBBT@Ao@@@@NQDAEE@IZGHNAF@@BHABDF@BCbKZAVEJJFNTEdAFANDH@dGHB^CZKNCdSRMTGllH@DHDdXúeAVD@hAòxPDPX^BFGLWF[JU@AEGEC@EHCAA"],["@@rULMDIBEAC@CCA@AC@CDCAGGUNMXWdRC"],["@@MQFIFEB@@ABAACDCA@DC@CHCAADACA@CB@@BB@AAD@AACAD@BAA@DAC@BC@ADAEEDACA@@ACB@@AB@AAFGCCUKDC@EkBÍTgBAHsBIZ@L[jE@@DCBBEA@CBA@BAWD@BIACAABAFC@FIEGACIHA@ECGFCBAASL@GFEBCBGAGEAQFCFCB@BEF@FA@C@EJSDKJKL@FIRENJ@LB`EHJJVH\\ÚG°DMTA@G"]],"encodeOffsets":[[[84324,45764]],[[84183,45809]],[[84274,46190]],[[84184,46208]],[[84150,45883]],[[84128,45846]],[[84137,45873]],[[84655,45970]],[[84246,45841]],[[84174,46064]]]},"properties":{"cp":[82.353656,44.840524],"name":"双河市","childNum":10}},{"id":"659008","type":"Feature","geometry":{"type":"MultiPolygon","coordinates":[["@@N@GKH@FDHBH@H@BD~CD^BDD@DCB@ABBBJC@BCBBDB@FA@EHADCLAFCDKLD@AP@@AB@BEECBCHAVADADBBABEDAFGPNKFAT@NHF@HAAADCACBAHFDAPOHAJGBCD@DAFBAFJFDLD@F@@EDCHADDLBBCLABCJBJD@BDHFA@LF@FHDB\\IFET@@AFAJKFC@GJAFBFCH@BCD@CCBCFBJAOCSBOGBKiMBAE]@@LCDBBKA[@A@@J_@š^]D@EcIÅOqCB@DD@@FJ@BBDAFDN@HBFHFBJAAETHJ@DDFBDBB@"],["@@eRB@GBFVDBPDBDNDHAN@FFJ@WKD"],["@@MCACOCCA@EMJGKHEAAFCBBBA@AHAA@rUMiEAACEAW@UAKEC@K@QJSDi@SAK@UHKJ]NGBOJHRZ`JA~LFpI@HD@lW[AECEA@"],["@@NWVWfDNXÆ¢oACA@@EBAPG@\\OGCOUOKDcH_j¯UKGoOI@eIQ@[A{IÀz"],["@@HFdLBGHOBMrB@QPCjLBUHa@GJQ²WCDeBYPHXFVCXBHTT@FBDG@EJDNABFDAJJFDG@AGEBC@AhBCKFAFFLEEQBIMO@GTFFHPJ`SPCCIFAISGEEKCCAGGGKCGEDABAACBGJIJEVCJWCEiITMD@FGDBDABA@CFABAJCDABABADCFB@CBADB@ED@@EFCBA@@JE@CFEFCD@BA@CFAAC@AAAFICECADAECAICABGCEDAEEHCWYDOR@KYSEiEA@ADI@COCOJEBAAACBGAESMKYSQAGWÅ±HAZoQGEJIt[D@RINKyÅúDP@FBBCFHF@DABEBBBABAFB@@BD@@DCBADBBABDBADCBDFCDEAADD@DBAB@DCBAACDEAADB@BABBBBC@ADEA@BA@BDDCBD@@E@BDCA@BCBDBBABBA@CDBFBD@DA@ALBFJHEHDFCDABAAAB@DEBCD@BEDCBIABD@BCBABBDAB@BADBBE@ABA@BBABGBEDAFA@@BABC@DBADB@@DDB@B@BCBBBDAADD@@BB@ABBDCDB@DABBCBH@@DE@BDE@ABFBABA@EACDDBABBBABED@BKABDEBBBEBDBABC@CACBBBH@BBGBABC@@BF@CBBBC@@DEBF@BBCD@BE@@BABFDBDE@@BCBHFAF@BAD@FGBDFF@BB@BCBBFADB@DCBDADC@@BH@@@CBDFG@@DBBJ@@B@@E@@BBD@BABAEA@EDABDFHBABE@ABBDHBBB@BIDFBABE@@BDFAFABA@@AA@AF@DEFHNAJQL"]],"encodeOffsets":[[[82733,44961]],[[83023,44988]],[[83022,45016]],[[82560,44805]],[[82372,45142]]]},"properties":{"cp":[80.63579,43.6832],"name":"可克达拉市","childNum":5}},{"id":"659009","type":"Feature","geometry":{"type":"Polygon","coordinates":[],"encodeOffsets":[]},"properties":{"cp":[79.287372,37.207994],"name":"昆玉市","childNum":0}}],"UTF8Encoding":true});
}));